import java.io
import java.lang
import java.net.http
import java.net.spi
import java.nio.channels
import java.nio.charset
import java.security
import java.security.cert
import java.util
import java.util.jar
import java.util.stream
import typing



class Authenticator:
    def __init__(self): ...
    @staticmethod
    def getDefault() -> 'Authenticator': ...
    @typing.overload
    @staticmethod
    def requestPasswordAuthentication(string: str, inetAddress: 'InetAddress', int: int, string2: str, string3: str, string4: str) -> 'PasswordAuthentication': ...
    @typing.overload
    @staticmethod
    def requestPasswordAuthentication(string: str, inetAddress: 'InetAddress', int: int, string2: str, string3: str, string4: str, uRL: 'URL', requestorType: 'Authenticator.RequestorType') -> 'PasswordAuthentication': ...
    @typing.overload
    @staticmethod
    def requestPasswordAuthentication(authenticator: 'Authenticator', string: str, inetAddress: 'InetAddress', int: int, string2: str, string3: str, string4: str, uRL: 'URL', requestorType: 'Authenticator.RequestorType') -> 'PasswordAuthentication': ...
    @typing.overload
    @staticmethod
    def requestPasswordAuthentication(inetAddress: 'InetAddress', int: int, string: str, string2: str, string3: str) -> 'PasswordAuthentication': ...
    def requestPasswordAuthenticationInstance(self, string: str, inetAddress: 'InetAddress', int: int, string2: str, string3: str, string4: str, uRL: 'URL', requestorType: 'Authenticator.RequestorType') -> 'PasswordAuthentication': ...
    @staticmethod
    def setDefault(authenticator: 'Authenticator') -> None: ...
    class RequestorType(java.lang.Enum['Authenticator.RequestorType']):
        PROXY: typing.ClassVar['Authenticator.RequestorType'] = ...
        SERVER: typing.ClassVar['Authenticator.RequestorType'] = ...
        _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
        @typing.overload
        @staticmethod
        def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
        @typing.overload
        @staticmethod
        def valueOf(string: str) -> 'Authenticator.RequestorType': ...
        @staticmethod
        def values() -> typing.List['Authenticator.RequestorType']: ...

class CacheRequest:
    def __init__(self): ...
    def abort(self) -> None: ...
    def getBody(self) -> java.io.OutputStream: ...

class CacheResponse:
    def __init__(self): ...
    def getBody(self) -> java.io.InputStream: ...
    def getHeaders(self) -> java.util.Map[str, java.util.List[str]]: ...

class ContentHandler:
    def __init__(self): ...
    @typing.overload
    def getContent(self, uRLConnection: 'URLConnection') -> typing.Any: ...
    @typing.overload
    def getContent(self, uRLConnection: 'URLConnection', classArray: typing.List[typing.Type]) -> typing.Any: ...

class ContentHandlerFactory:
    def createContentHandler(self, string: str) -> ContentHandler: ...

class CookieHandler:
    def __init__(self): ...
    def get(self, uRI: 'URI', map: typing.Union[java.util.Map[str, java.util.List[str]], typing.Mapping[str, java.util.List[str]]]) -> java.util.Map[str, java.util.List[str]]: ...
    @staticmethod
    def getDefault() -> 'CookieHandler': ...
    def put(self, uRI: 'URI', map: typing.Union[java.util.Map[str, java.util.List[str]], typing.Mapping[str, java.util.List[str]]]) -> None: ...
    @staticmethod
    def setDefault(cookieHandler: 'CookieHandler') -> None: ...

class CookiePolicy:
    ACCEPT_ALL: typing.ClassVar['CookiePolicy'] = ...
    ACCEPT_NONE: typing.ClassVar['CookiePolicy'] = ...
    ACCEPT_ORIGINAL_SERVER: typing.ClassVar['CookiePolicy'] = ...
    def shouldAccept(self, uRI: 'URI', httpCookie: 'HttpCookie') -> bool: ...

class CookieStore:
    def add(self, uRI: 'URI', httpCookie: 'HttpCookie') -> None: ...
    def get(self, uRI: 'URI') -> java.util.List['HttpCookie']: ...
    def getCookies(self) -> java.util.List['HttpCookie']: ...
    def getURIs(self) -> java.util.List['URI']: ...
    def remove(self, uRI: 'URI', httpCookie: 'HttpCookie') -> bool: ...
    def removeAll(self) -> bool: ...

class DatagramPacket:
    @typing.overload
    def __init__(self, byteArray: typing.List[int], int: int): ...
    @typing.overload
    def __init__(self, byteArray: typing.List[int], int: int, int2: int): ...
    @typing.overload
    def __init__(self, byteArray: typing.List[int], int: int, int2: int, inetAddress: 'InetAddress', int3: int): ...
    @typing.overload
    def __init__(self, byteArray: typing.List[int], int: int, int2: int, socketAddress: 'SocketAddress'): ...
    @typing.overload
    def __init__(self, byteArray: typing.List[int], int: int, inetAddress: 'InetAddress', int2: int): ...
    @typing.overload
    def __init__(self, byteArray: typing.List[int], int: int, socketAddress: 'SocketAddress'): ...
    def getAddress(self) -> 'InetAddress': ...
    def getData(self) -> typing.List[int]: ...
    def getLength(self) -> int: ...
    def getOffset(self) -> int: ...
    def getPort(self) -> int: ...
    def getSocketAddress(self) -> 'SocketAddress': ...
    def setAddress(self, inetAddress: 'InetAddress') -> None: ...
    @typing.overload
    def setData(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def setData(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    def setLength(self, int: int) -> None: ...
    def setPort(self, int: int) -> None: ...
    def setSocketAddress(self, socketAddress: 'SocketAddress') -> None: ...

class DatagramSocket(java.io.Closeable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, int: int, inetAddress: 'InetAddress'): ...
    @typing.overload
    def __init__(self, socketAddress: 'SocketAddress'): ...
    def bind(self, socketAddress: 'SocketAddress') -> None: ...
    def close(self) -> None: ...
    @typing.overload
    def connect(self, inetAddress: 'InetAddress', int: int) -> None: ...
    @typing.overload
    def connect(self, socketAddress: 'SocketAddress') -> None: ...
    def disconnect(self) -> None: ...
    def getBroadcast(self) -> bool: ...
    def getChannel(self) -> java.nio.channels.DatagramChannel: ...
    def getInetAddress(self) -> 'InetAddress': ...
    def getLocalAddress(self) -> 'InetAddress': ...
    def getLocalPort(self) -> int: ...
    def getLocalSocketAddress(self) -> 'SocketAddress': ...
    _getOption__T = typing.TypeVar('_getOption__T')  # <T>
    def getOption(self, socketOption: 'SocketOption'[_getOption__T]) -> _getOption__T: ...
    def getPort(self) -> int: ...
    def getReceiveBufferSize(self) -> int: ...
    def getRemoteSocketAddress(self) -> 'SocketAddress': ...
    def getReuseAddress(self) -> bool: ...
    def getSendBufferSize(self) -> int: ...
    def getSoTimeout(self) -> int: ...
    def getTrafficClass(self) -> int: ...
    def isBound(self) -> bool: ...
    def isClosed(self) -> bool: ...
    def isConnected(self) -> bool: ...
    def receive(self, datagramPacket: DatagramPacket) -> None: ...
    def send(self, datagramPacket: DatagramPacket) -> None: ...
    def setBroadcast(self, boolean: bool) -> None: ...
    @staticmethod
    def setDatagramSocketImplFactory(datagramSocketImplFactory: 'DatagramSocketImplFactory') -> None: ...
    _setOption__T = typing.TypeVar('_setOption__T')  # <T>
    def setOption(self, socketOption: 'SocketOption'[_setOption__T], t: _setOption__T) -> 'DatagramSocket': ...
    def setReceiveBufferSize(self, int: int) -> None: ...
    def setReuseAddress(self, boolean: bool) -> None: ...
    def setSendBufferSize(self, int: int) -> None: ...
    def setSoTimeout(self, int: int) -> None: ...
    def setTrafficClass(self, int: int) -> None: ...
    def supportedOptions(self) -> java.util.Set['SocketOption'[typing.Any]]: ...

class DatagramSocketImplFactory:
    def createDatagramSocketImpl(self) -> 'DatagramSocketImpl': ...

class FileNameMap:
    def getContentTypeFor(self, string: str) -> str: ...

class HttpCookie(java.lang.Cloneable):
    def __init__(self, string: str, string2: str): ...
    def clone(self) -> typing.Any: ...
    @staticmethod
    def domainMatches(string: str, string2: str) -> bool: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getComment(self) -> str: ...
    def getCommentURL(self) -> str: ...
    def getDiscard(self) -> bool: ...
    def getDomain(self) -> str: ...
    def getMaxAge(self) -> int: ...
    def getName(self) -> str: ...
    def getPath(self) -> str: ...
    def getPortlist(self) -> str: ...
    def getSecure(self) -> bool: ...
    def getValue(self) -> str: ...
    def getVersion(self) -> int: ...
    def hasExpired(self) -> bool: ...
    def hashCode(self) -> int: ...
    def isHttpOnly(self) -> bool: ...
    @staticmethod
    def parse(string: str) -> java.util.List['HttpCookie']: ...
    def setComment(self, string: str) -> None: ...
    def setCommentURL(self, string: str) -> None: ...
    def setDiscard(self, boolean: bool) -> None: ...
    def setDomain(self, string: str) -> None: ...
    def setHttpOnly(self, boolean: bool) -> None: ...
    def setMaxAge(self, long: int) -> None: ...
    def setPath(self, string: str) -> None: ...
    def setPortlist(self, string: str) -> None: ...
    def setSecure(self, boolean: bool) -> None: ...
    def setValue(self, string: str) -> None: ...
    def setVersion(self, int: int) -> None: ...
    def toString(self) -> str: ...

class HttpRetryException(java.io.IOException):
    @typing.overload
    def __init__(self, string: str, int: int): ...
    @typing.overload
    def __init__(self, string: str, int: int, string2: str): ...
    def getLocation(self) -> str: ...
    def getReason(self) -> str: ...
    def responseCode(self) -> int: ...

class IDN:
    ALLOW_UNASSIGNED: typing.ClassVar[int] = ...
    USE_STD3_ASCII_RULES: typing.ClassVar[int] = ...
    @typing.overload
    @staticmethod
    def toASCII(string: str) -> str: ...
    @typing.overload
    @staticmethod
    def toASCII(string: str, int: int) -> str: ...
    @typing.overload
    @staticmethod
    def toUnicode(string: str) -> str: ...
    @typing.overload
    @staticmethod
    def toUnicode(string: str, int: int) -> str: ...

class InetAddress(java.io.Serializable):
    def equals(self, object: typing.Any) -> bool: ...
    def getAddress(self) -> typing.List[int]: ...
    @staticmethod
    def getAllByName(string: str) -> typing.List['InetAddress']: ...
    @typing.overload
    @staticmethod
    def getByAddress(byteArray: typing.List[int]) -> 'InetAddress': ...
    @typing.overload
    @staticmethod
    def getByAddress(string: str, byteArray: typing.List[int]) -> 'InetAddress': ...
    @staticmethod
    def getByName(string: str) -> 'InetAddress': ...
    def getCanonicalHostName(self) -> str: ...
    def getHostAddress(self) -> str: ...
    def getHostName(self) -> str: ...
    @staticmethod
    def getLocalHost() -> 'InetAddress': ...
    @staticmethod
    def getLoopbackAddress() -> 'InetAddress': ...
    def hashCode(self) -> int: ...
    def isAnyLocalAddress(self) -> bool: ...
    def isLinkLocalAddress(self) -> bool: ...
    def isLoopbackAddress(self) -> bool: ...
    def isMCGlobal(self) -> bool: ...
    def isMCLinkLocal(self) -> bool: ...
    def isMCNodeLocal(self) -> bool: ...
    def isMCOrgLocal(self) -> bool: ...
    def isMCSiteLocal(self) -> bool: ...
    def isMulticastAddress(self) -> bool: ...
    @typing.overload
    def isReachable(self, int: int) -> bool: ...
    @typing.overload
    def isReachable(self, networkInterface: 'NetworkInterface', int: int, int2: int) -> bool: ...
    def isSiteLocalAddress(self) -> bool: ...
    def toString(self) -> str: ...

class InterfaceAddress:
    def equals(self, object: typing.Any) -> bool: ...
    def getAddress(self) -> InetAddress: ...
    def getBroadcast(self) -> InetAddress: ...
    def getNetworkPrefixLength(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class MalformedURLException(java.io.IOException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class NetPermission(java.security.BasicPermission):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str): ...

class NetworkInterface:
    def equals(self, object: typing.Any) -> bool: ...
    @staticmethod
    def getByIndex(int: int) -> 'NetworkInterface': ...
    @staticmethod
    def getByInetAddress(inetAddress: InetAddress) -> 'NetworkInterface': ...
    @staticmethod
    def getByName(string: str) -> 'NetworkInterface': ...
    def getDisplayName(self) -> str: ...
    def getHardwareAddress(self) -> typing.List[int]: ...
    def getIndex(self) -> int: ...
    def getInetAddresses(self) -> java.util.Enumeration[InetAddress]: ...
    def getInterfaceAddresses(self) -> java.util.List[InterfaceAddress]: ...
    def getMTU(self) -> int: ...
    def getName(self) -> str: ...
    @staticmethod
    def getNetworkInterfaces() -> java.util.Enumeration['NetworkInterface']: ...
    def getParent(self) -> 'NetworkInterface': ...
    def getSubInterfaces(self) -> java.util.Enumeration['NetworkInterface']: ...
    def hashCode(self) -> int: ...
    def inetAddresses(self) -> java.util.stream.Stream[InetAddress]: ...
    def isLoopback(self) -> bool: ...
    def isPointToPoint(self) -> bool: ...
    def isUp(self) -> bool: ...
    def isVirtual(self) -> bool: ...
    @staticmethod
    def networkInterfaces() -> java.util.stream.Stream['NetworkInterface']: ...
    def subInterfaces(self) -> java.util.stream.Stream['NetworkInterface']: ...
    def supportsMulticast(self) -> bool: ...
    def toString(self) -> str: ...

class PasswordAuthentication:
    def __init__(self, string: str, charArray: typing.List[str]): ...
    def getPassword(self) -> typing.List[str]: ...
    def getUserName(self) -> str: ...

class ProtocolException(java.io.IOException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class ProtocolFamily:
    def name(self) -> str: ...

class Proxy:
    NO_PROXY: typing.ClassVar['Proxy'] = ...
    def __init__(self, type: 'Proxy.Type', socketAddress: 'SocketAddress'): ...
    def address(self) -> 'SocketAddress': ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def type(self) -> 'Proxy.Type': ...
    class Type(java.lang.Enum['Proxy.Type']):
        DIRECT: typing.ClassVar['Proxy.Type'] = ...
        HTTP: typing.ClassVar['Proxy.Type'] = ...
        SOCKS: typing.ClassVar['Proxy.Type'] = ...
        _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
        @typing.overload
        @staticmethod
        def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
        @typing.overload
        @staticmethod
        def valueOf(string: str) -> 'Proxy.Type': ...
        @staticmethod
        def values() -> typing.List['Proxy.Type']: ...

class ProxySelector:
    def __init__(self): ...
    def connectFailed(self, uRI: 'URI', socketAddress: 'SocketAddress', iOException: java.io.IOException) -> None: ...
    @staticmethod
    def getDefault() -> 'ProxySelector': ...
    @staticmethod
    def of(inetSocketAddress: 'InetSocketAddress') -> 'ProxySelector': ...
    def select(self, uRI: 'URI') -> java.util.List[Proxy]: ...
    @staticmethod
    def setDefault(proxySelector: 'ProxySelector') -> None: ...

class ResponseCache:
    def __init__(self): ...
    def get(self, uRI: 'URI', string: str, map: typing.Union[java.util.Map[str, java.util.List[str]], typing.Mapping[str, java.util.List[str]]]) -> CacheResponse: ...
    @staticmethod
    def getDefault() -> 'ResponseCache': ...
    def put(self, uRI: 'URI', uRLConnection: 'URLConnection') -> CacheRequest: ...
    @staticmethod
    def setDefault(responseCache: 'ResponseCache') -> None: ...

class ServerSocket(java.io.Closeable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int, inetAddress: InetAddress): ...
    def accept(self) -> 'Socket': ...
    @typing.overload
    def bind(self, socketAddress: 'SocketAddress') -> None: ...
    @typing.overload
    def bind(self, socketAddress: 'SocketAddress', int: int) -> None: ...
    def close(self) -> None: ...
    def getChannel(self) -> java.nio.channels.ServerSocketChannel: ...
    def getInetAddress(self) -> InetAddress: ...
    def getLocalPort(self) -> int: ...
    def getLocalSocketAddress(self) -> 'SocketAddress': ...
    _getOption__T = typing.TypeVar('_getOption__T')  # <T>
    def getOption(self, socketOption: 'SocketOption'[_getOption__T]) -> _getOption__T: ...
    def getReceiveBufferSize(self) -> int: ...
    def getReuseAddress(self) -> bool: ...
    def getSoTimeout(self) -> int: ...
    def isBound(self) -> bool: ...
    def isClosed(self) -> bool: ...
    _setOption__T = typing.TypeVar('_setOption__T')  # <T>
    def setOption(self, socketOption: 'SocketOption'[_setOption__T], t: _setOption__T) -> 'ServerSocket': ...
    def setPerformancePreferences(self, int: int, int2: int, int3: int) -> None: ...
    def setReceiveBufferSize(self, int: int) -> None: ...
    def setReuseAddress(self, boolean: bool) -> None: ...
    def setSoTimeout(self, int: int) -> None: ...
    @staticmethod
    def setSocketFactory(socketImplFactory: 'SocketImplFactory') -> None: ...
    def supportedOptions(self) -> java.util.Set['SocketOption'[typing.Any]]: ...
    def toString(self) -> str: ...

class Socket(java.io.Closeable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str, int: int): ...
    @typing.overload
    def __init__(self, string: str, int: int, boolean: bool): ...
    @typing.overload
    def __init__(self, string: str, int: int, inetAddress: InetAddress, int2: int): ...
    @typing.overload
    def __init__(self, inetAddress: InetAddress, int: int): ...
    @typing.overload
    def __init__(self, inetAddress: InetAddress, int: int, boolean: bool): ...
    @typing.overload
    def __init__(self, inetAddress: InetAddress, int: int, inetAddress2: InetAddress, int2: int): ...
    @typing.overload
    def __init__(self, proxy: Proxy): ...
    def bind(self, socketAddress: 'SocketAddress') -> None: ...
    def close(self) -> None: ...
    @typing.overload
    def connect(self, socketAddress: 'SocketAddress') -> None: ...
    @typing.overload
    def connect(self, socketAddress: 'SocketAddress', int: int) -> None: ...
    def getChannel(self) -> java.nio.channels.SocketChannel: ...
    def getInetAddress(self) -> InetAddress: ...
    def getInputStream(self) -> java.io.InputStream: ...
    def getKeepAlive(self) -> bool: ...
    def getLocalAddress(self) -> InetAddress: ...
    def getLocalPort(self) -> int: ...
    def getLocalSocketAddress(self) -> 'SocketAddress': ...
    def getOOBInline(self) -> bool: ...
    _getOption__T = typing.TypeVar('_getOption__T')  # <T>
    def getOption(self, socketOption: 'SocketOption'[_getOption__T]) -> _getOption__T: ...
    def getOutputStream(self) -> java.io.OutputStream: ...
    def getPort(self) -> int: ...
    def getReceiveBufferSize(self) -> int: ...
    def getRemoteSocketAddress(self) -> 'SocketAddress': ...
    def getReuseAddress(self) -> bool: ...
    def getSendBufferSize(self) -> int: ...
    def getSoLinger(self) -> int: ...
    def getSoTimeout(self) -> int: ...
    def getTcpNoDelay(self) -> bool: ...
    def getTrafficClass(self) -> int: ...
    def isBound(self) -> bool: ...
    def isClosed(self) -> bool: ...
    def isConnected(self) -> bool: ...
    def isInputShutdown(self) -> bool: ...
    def isOutputShutdown(self) -> bool: ...
    def sendUrgentData(self, int: int) -> None: ...
    def setKeepAlive(self, boolean: bool) -> None: ...
    def setOOBInline(self, boolean: bool) -> None: ...
    _setOption__T = typing.TypeVar('_setOption__T')  # <T>
    def setOption(self, socketOption: 'SocketOption'[_setOption__T], t: _setOption__T) -> 'Socket': ...
    def setPerformancePreferences(self, int: int, int2: int, int3: int) -> None: ...
    def setReceiveBufferSize(self, int: int) -> None: ...
    def setReuseAddress(self, boolean: bool) -> None: ...
    def setSendBufferSize(self, int: int) -> None: ...
    def setSoLinger(self, boolean: bool, int: int) -> None: ...
    def setSoTimeout(self, int: int) -> None: ...
    @staticmethod
    def setSocketImplFactory(socketImplFactory: 'SocketImplFactory') -> None: ...
    def setTcpNoDelay(self, boolean: bool) -> None: ...
    def setTrafficClass(self, int: int) -> None: ...
    def shutdownInput(self) -> None: ...
    def shutdownOutput(self) -> None: ...
    def supportedOptions(self) -> java.util.Set['SocketOption'[typing.Any]]: ...
    def toString(self) -> str: ...

class SocketAddress(java.io.Serializable):
    def __init__(self): ...

class SocketException(java.io.IOException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class SocketImplFactory:
    def createSocketImpl(self) -> 'SocketImpl': ...

_SocketOption__T = typing.TypeVar('_SocketOption__T')  # <T>
class SocketOption(typing.Generic[_SocketOption__T]):
    def name(self) -> str: ...
    def type(self) -> typing.Type[_SocketOption__T]: ...

class SocketOptions:
    TCP_NODELAY: typing.ClassVar[int] = ...
    SO_BINDADDR: typing.ClassVar[int] = ...
    SO_REUSEADDR: typing.ClassVar[int] = ...
    SO_REUSEPORT: typing.ClassVar[int] = ...
    SO_BROADCAST: typing.ClassVar[int] = ...
    IP_MULTICAST_IF: typing.ClassVar[int] = ...
    IP_MULTICAST_IF2: typing.ClassVar[int] = ...
    IP_MULTICAST_LOOP: typing.ClassVar[int] = ...
    IP_TOS: typing.ClassVar[int] = ...
    SO_LINGER: typing.ClassVar[int] = ...
    SO_TIMEOUT: typing.ClassVar[int] = ...
    SO_SNDBUF: typing.ClassVar[int] = ...
    SO_RCVBUF: typing.ClassVar[int] = ...
    SO_KEEPALIVE: typing.ClassVar[int] = ...
    SO_OOBINLINE: typing.ClassVar[int] = ...
    def getOption(self, int: int) -> typing.Any: ...
    def setOption(self, int: int, object: typing.Any) -> None: ...

class SocketPermission(java.security.Permission, java.io.Serializable):
    def __init__(self, string: str, string2: str): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getActions(self) -> str: ...
    def hashCode(self) -> int: ...
    def implies(self, permission: java.security.Permission) -> bool: ...
    def newPermissionCollection(self) -> java.security.PermissionCollection: ...

class SocketTimeoutException(java.io.InterruptedIOException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class StandardSocketOptions:
    SO_BROADCAST: typing.ClassVar[SocketOption] = ...
    SO_KEEPALIVE: typing.ClassVar[SocketOption] = ...
    SO_SNDBUF: typing.ClassVar[SocketOption] = ...
    SO_RCVBUF: typing.ClassVar[SocketOption] = ...
    SO_REUSEADDR: typing.ClassVar[SocketOption] = ...
    SO_REUSEPORT: typing.ClassVar[SocketOption] = ...
    SO_LINGER: typing.ClassVar[SocketOption] = ...
    IP_TOS: typing.ClassVar[SocketOption] = ...
    IP_MULTICAST_IF: typing.ClassVar[SocketOption] = ...
    IP_MULTICAST_TTL: typing.ClassVar[SocketOption] = ...
    IP_MULTICAST_LOOP: typing.ClassVar[SocketOption] = ...
    TCP_NODELAY: typing.ClassVar[SocketOption] = ...

class URI(java.lang.Comparable['URI'], java.io.Serializable):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str, string3: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str, string3: str, int: int, string4: str, string5: str, string6: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str, string3: str, string4: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str, string3: str, string4: str, string5: str): ...
    def compareTo(self, uRI: 'URI') -> int: ...
    @staticmethod
    def create(string: str) -> 'URI': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getAuthority(self) -> str: ...
    def getFragment(self) -> str: ...
    def getHost(self) -> str: ...
    def getPath(self) -> str: ...
    def getPort(self) -> int: ...
    def getQuery(self) -> str: ...
    def getRawAuthority(self) -> str: ...
    def getRawFragment(self) -> str: ...
    def getRawPath(self) -> str: ...
    def getRawQuery(self) -> str: ...
    def getRawSchemeSpecificPart(self) -> str: ...
    def getRawUserInfo(self) -> str: ...
    def getScheme(self) -> str: ...
    def getSchemeSpecificPart(self) -> str: ...
    def getUserInfo(self) -> str: ...
    def hashCode(self) -> int: ...
    def isAbsolute(self) -> bool: ...
    def isOpaque(self) -> bool: ...
    def normalize(self) -> 'URI': ...
    def parseServerAuthority(self) -> 'URI': ...
    def relativize(self, uRI: 'URI') -> 'URI': ...
    @typing.overload
    def resolve(self, string: str) -> 'URI': ...
    @typing.overload
    def resolve(self, uRI: 'URI') -> 'URI': ...
    def toASCIIString(self) -> str: ...
    def toString(self) -> str: ...
    def toURL(self) -> 'URL': ...

class URISyntaxException(java.lang.Exception):
    @typing.overload
    def __init__(self, string: str, string2: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str, int: int): ...
    def getIndex(self) -> int: ...
    def getInput(self) -> str: ...
    def getMessage(self) -> str: ...
    def getReason(self) -> str: ...

class URL(java.io.Serializable):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str, int: int, string3: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str, int: int, string3: str, uRLStreamHandler: 'URLStreamHandler'): ...
    @typing.overload
    def __init__(self, string: str, string2: str, string3: str): ...
    @typing.overload
    def __init__(self, uRL: 'URL', string: str): ...
    @typing.overload
    def __init__(self, uRL: 'URL', string: str, uRLStreamHandler: 'URLStreamHandler'): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getAuthority(self) -> str: ...
    @typing.overload
    def getContent(self) -> typing.Any: ...
    @typing.overload
    def getContent(self, classArray: typing.List[typing.Type[typing.Any]]) -> typing.Any: ...
    def getDefaultPort(self) -> int: ...
    def getFile(self) -> str: ...
    def getHost(self) -> str: ...
    def getPath(self) -> str: ...
    def getPort(self) -> int: ...
    def getProtocol(self) -> str: ...
    def getQuery(self) -> str: ...
    def getRef(self) -> str: ...
    def getUserInfo(self) -> str: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def openConnection(self) -> 'URLConnection': ...
    @typing.overload
    def openConnection(self, proxy: Proxy) -> 'URLConnection': ...
    def openStream(self) -> java.io.InputStream: ...
    def sameFile(self, uRL: 'URL') -> bool: ...
    @staticmethod
    def setURLStreamHandlerFactory(uRLStreamHandlerFactory: 'URLStreamHandlerFactory') -> None: ...
    def toExternalForm(self) -> str: ...
    def toString(self) -> str: ...
    def toURI(self) -> URI: ...

class URLClassLoader(java.security.SecureClassLoader, java.io.Closeable):
    @typing.overload
    def __init__(self, string: str, uRLArray: typing.List[URL], classLoader: java.lang.ClassLoader): ...
    @typing.overload
    def __init__(self, string: str, uRLArray: typing.List[URL], classLoader: java.lang.ClassLoader, uRLStreamHandlerFactory: 'URLStreamHandlerFactory'): ...
    @typing.overload
    def __init__(self, uRLArray: typing.List[URL]): ...
    @typing.overload
    def __init__(self, uRLArray: typing.List[URL], classLoader: java.lang.ClassLoader): ...
    @typing.overload
    def __init__(self, uRLArray: typing.List[URL], classLoader: java.lang.ClassLoader, uRLStreamHandlerFactory: 'URLStreamHandlerFactory'): ...
    def close(self) -> None: ...
    def findResource(self, string: str) -> URL: ...
    def findResources(self, string: str) -> java.util.Enumeration[URL]: ...
    def getResourceAsStream(self, string: str) -> java.io.InputStream: ...
    def getURLs(self) -> typing.List[URL]: ...
    @typing.overload
    @staticmethod
    def newInstance(uRLArray: typing.List[URL]) -> 'URLClassLoader': ...
    @typing.overload
    @staticmethod
    def newInstance(uRLArray: typing.List[URL], classLoader: java.lang.ClassLoader) -> 'URLClassLoader': ...

class URLConnection:
    def addRequestProperty(self, string: str, string2: str) -> None: ...
    def connect(self) -> None: ...
    def getAllowUserInteraction(self) -> bool: ...
    def getConnectTimeout(self) -> int: ...
    @typing.overload
    def getContent(self) -> typing.Any: ...
    @typing.overload
    def getContent(self, classArray: typing.List[typing.Type[typing.Any]]) -> typing.Any: ...
    def getContentEncoding(self) -> str: ...
    def getContentLength(self) -> int: ...
    def getContentLengthLong(self) -> int: ...
    def getContentType(self) -> str: ...
    def getDate(self) -> int: ...
    @staticmethod
    def getDefaultAllowUserInteraction() -> bool: ...
    @staticmethod
    def getDefaultRequestProperty(string: str) -> str: ...
    @typing.overload
    def getDefaultUseCaches(self) -> bool: ...
    @typing.overload
    @staticmethod
    def getDefaultUseCaches(string: str) -> bool: ...
    def getDoInput(self) -> bool: ...
    def getDoOutput(self) -> bool: ...
    def getExpiration(self) -> int: ...
    @staticmethod
    def getFileNameMap() -> FileNameMap: ...
    @typing.overload
    def getHeaderField(self, int: int) -> str: ...
    @typing.overload
    def getHeaderField(self, string: str) -> str: ...
    def getHeaderFieldDate(self, string: str, long: int) -> int: ...
    def getHeaderFieldInt(self, string: str, int: int) -> int: ...
    def getHeaderFieldKey(self, int: int) -> str: ...
    def getHeaderFieldLong(self, string: str, long: int) -> int: ...
    def getHeaderFields(self) -> java.util.Map[str, java.util.List[str]]: ...
    def getIfModifiedSince(self) -> int: ...
    def getInputStream(self) -> java.io.InputStream: ...
    def getLastModified(self) -> int: ...
    def getOutputStream(self) -> java.io.OutputStream: ...
    def getPermission(self) -> java.security.Permission: ...
    def getReadTimeout(self) -> int: ...
    def getRequestProperties(self) -> java.util.Map[str, java.util.List[str]]: ...
    def getRequestProperty(self, string: str) -> str: ...
    def getURL(self) -> URL: ...
    def getUseCaches(self) -> bool: ...
    @staticmethod
    def guessContentTypeFromName(string: str) -> str: ...
    @staticmethod
    def guessContentTypeFromStream(inputStream: java.io.InputStream) -> str: ...
    def setAllowUserInteraction(self, boolean: bool) -> None: ...
    def setConnectTimeout(self, int: int) -> None: ...
    @staticmethod
    def setContentHandlerFactory(contentHandlerFactory: ContentHandlerFactory) -> None: ...
    @staticmethod
    def setDefaultAllowUserInteraction(boolean: bool) -> None: ...
    @staticmethod
    def setDefaultRequestProperty(string: str, string2: str) -> None: ...
    @typing.overload
    @staticmethod
    def setDefaultUseCaches(string: str, boolean: bool) -> None: ...
    @typing.overload
    def setDefaultUseCaches(self, boolean: bool) -> None: ...
    def setDoInput(self, boolean: bool) -> None: ...
    def setDoOutput(self, boolean: bool) -> None: ...
    @staticmethod
    def setFileNameMap(fileNameMap: FileNameMap) -> None: ...
    def setIfModifiedSince(self, long: int) -> None: ...
    def setReadTimeout(self, int: int) -> None: ...
    def setRequestProperty(self, string: str, string2: str) -> None: ...
    def setUseCaches(self, boolean: bool) -> None: ...
    def toString(self) -> str: ...

class URLDecoder:
    def __init__(self): ...
    @typing.overload
    @staticmethod
    def decode(string: str) -> str: ...
    @typing.overload
    @staticmethod
    def decode(string: str, string2: str) -> str: ...
    @typing.overload
    @staticmethod
    def decode(string: str, charset: java.nio.charset.Charset) -> str: ...

class URLEncoder:
    @typing.overload
    @staticmethod
    def encode(string: str) -> str: ...
    @typing.overload
    @staticmethod
    def encode(string: str, string2: str) -> str: ...
    @typing.overload
    @staticmethod
    def encode(string: str, charset: java.nio.charset.Charset) -> str: ...

class URLPermission(java.security.Permission):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getActions(self) -> str: ...
    def hashCode(self) -> int: ...
    def implies(self, permission: java.security.Permission) -> bool: ...

class URLStreamHandler:
    def __init__(self): ...

class URLStreamHandlerFactory:
    def createURLStreamHandler(self, string: str) -> URLStreamHandler: ...

class UnknownHostException(java.io.IOException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class UnknownServiceException(java.io.IOException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class BindException(SocketException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class ConnectException(SocketException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class CookieManager(CookieHandler):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, cookieStore: CookieStore, cookiePolicy: CookiePolicy): ...
    def get(self, uRI: URI, map: typing.Union[java.util.Map[str, java.util.List[str]], typing.Mapping[str, java.util.List[str]]]) -> java.util.Map[str, java.util.List[str]]: ...
    def getCookieStore(self) -> CookieStore: ...
    def put(self, uRI: URI, map: typing.Union[java.util.Map[str, java.util.List[str]], typing.Mapping[str, java.util.List[str]]]) -> None: ...
    def setCookiePolicy(self, cookiePolicy: CookiePolicy) -> None: ...

class DatagramSocketImpl(SocketOptions):
    def __init__(self): ...

class HttpURLConnection(URLConnection):
    HTTP_OK: typing.ClassVar[int] = ...
    HTTP_CREATED: typing.ClassVar[int] = ...
    HTTP_ACCEPTED: typing.ClassVar[int] = ...
    HTTP_NOT_AUTHORITATIVE: typing.ClassVar[int] = ...
    HTTP_NO_CONTENT: typing.ClassVar[int] = ...
    HTTP_RESET: typing.ClassVar[int] = ...
    HTTP_PARTIAL: typing.ClassVar[int] = ...
    HTTP_MULT_CHOICE: typing.ClassVar[int] = ...
    HTTP_MOVED_PERM: typing.ClassVar[int] = ...
    HTTP_MOVED_TEMP: typing.ClassVar[int] = ...
    HTTP_SEE_OTHER: typing.ClassVar[int] = ...
    HTTP_NOT_MODIFIED: typing.ClassVar[int] = ...
    HTTP_USE_PROXY: typing.ClassVar[int] = ...
    HTTP_BAD_REQUEST: typing.ClassVar[int] = ...
    HTTP_UNAUTHORIZED: typing.ClassVar[int] = ...
    HTTP_PAYMENT_REQUIRED: typing.ClassVar[int] = ...
    HTTP_FORBIDDEN: typing.ClassVar[int] = ...
    HTTP_NOT_FOUND: typing.ClassVar[int] = ...
    HTTP_BAD_METHOD: typing.ClassVar[int] = ...
    HTTP_NOT_ACCEPTABLE: typing.ClassVar[int] = ...
    HTTP_PROXY_AUTH: typing.ClassVar[int] = ...
    HTTP_CLIENT_TIMEOUT: typing.ClassVar[int] = ...
    HTTP_CONFLICT: typing.ClassVar[int] = ...
    HTTP_GONE: typing.ClassVar[int] = ...
    HTTP_LENGTH_REQUIRED: typing.ClassVar[int] = ...
    HTTP_PRECON_FAILED: typing.ClassVar[int] = ...
    HTTP_ENTITY_TOO_LARGE: typing.ClassVar[int] = ...
    HTTP_REQ_TOO_LONG: typing.ClassVar[int] = ...
    HTTP_UNSUPPORTED_TYPE: typing.ClassVar[int] = ...
    HTTP_SERVER_ERROR: typing.ClassVar[int] = ...
    HTTP_INTERNAL_ERROR: typing.ClassVar[int] = ...
    HTTP_NOT_IMPLEMENTED: typing.ClassVar[int] = ...
    HTTP_BAD_GATEWAY: typing.ClassVar[int] = ...
    HTTP_UNAVAILABLE: typing.ClassVar[int] = ...
    HTTP_GATEWAY_TIMEOUT: typing.ClassVar[int] = ...
    HTTP_VERSION: typing.ClassVar[int] = ...
    def disconnect(self) -> None: ...
    def getErrorStream(self) -> java.io.InputStream: ...
    @staticmethod
    def getFollowRedirects() -> bool: ...
    @typing.overload
    def getHeaderField(self, int: int) -> str: ...
    @typing.overload
    def getHeaderField(self, string: str) -> str: ...
    def getHeaderFieldDate(self, string: str, long: int) -> int: ...
    def getHeaderFieldKey(self, int: int) -> str: ...
    def getInstanceFollowRedirects(self) -> bool: ...
    def getPermission(self) -> java.security.Permission: ...
    def getRequestMethod(self) -> str: ...
    def getResponseCode(self) -> int: ...
    def getResponseMessage(self) -> str: ...
    def setAuthenticator(self, authenticator: Authenticator) -> None: ...
    def setChunkedStreamingMode(self, int: int) -> None: ...
    @typing.overload
    def setFixedLengthStreamingMode(self, int: int) -> None: ...
    @typing.overload
    def setFixedLengthStreamingMode(self, long: int) -> None: ...
    @staticmethod
    def setFollowRedirects(boolean: bool) -> None: ...
    def setInstanceFollowRedirects(self, boolean: bool) -> None: ...
    def setRequestMethod(self, string: str) -> None: ...
    def usingProxy(self) -> bool: ...

class Inet4Address(InetAddress):
    def equals(self, object: typing.Any) -> bool: ...
    def getAddress(self) -> typing.List[int]: ...
    def getHostAddress(self) -> str: ...
    def hashCode(self) -> int: ...
    def isAnyLocalAddress(self) -> bool: ...
    def isLinkLocalAddress(self) -> bool: ...
    def isLoopbackAddress(self) -> bool: ...
    def isMCGlobal(self) -> bool: ...
    def isMCLinkLocal(self) -> bool: ...
    def isMCNodeLocal(self) -> bool: ...
    def isMCOrgLocal(self) -> bool: ...
    def isMCSiteLocal(self) -> bool: ...
    def isMulticastAddress(self) -> bool: ...
    def isSiteLocalAddress(self) -> bool: ...

class Inet6Address(InetAddress):
    def equals(self, object: typing.Any) -> bool: ...
    def getAddress(self) -> typing.List[int]: ...
    @typing.overload
    @staticmethod
    def getByAddress(string: str, byteArray: typing.List[int], int: int) -> 'Inet6Address': ...
    @typing.overload
    @staticmethod
    def getByAddress(string: str, byteArray: typing.List[int], networkInterface: NetworkInterface) -> 'Inet6Address': ...
    @typing.overload
    @staticmethod
    def getByAddress(byteArray: typing.List[int]) -> InetAddress: ...
    @typing.overload
    @staticmethod
    def getByAddress(string: str, byteArray: typing.List[int]) -> InetAddress: ...
    def getHostAddress(self) -> str: ...
    def getScopeId(self) -> int: ...
    def getScopedInterface(self) -> NetworkInterface: ...
    def hashCode(self) -> int: ...
    def isAnyLocalAddress(self) -> bool: ...
    def isIPv4CompatibleAddress(self) -> bool: ...
    def isLinkLocalAddress(self) -> bool: ...
    def isLoopbackAddress(self) -> bool: ...
    def isMCGlobal(self) -> bool: ...
    def isMCLinkLocal(self) -> bool: ...
    def isMCNodeLocal(self) -> bool: ...
    def isMCOrgLocal(self) -> bool: ...
    def isMCSiteLocal(self) -> bool: ...
    def isMulticastAddress(self) -> bool: ...
    def isSiteLocalAddress(self) -> bool: ...

class InetSocketAddress(SocketAddress):
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, string: str, int: int): ...
    @typing.overload
    def __init__(self, inetAddress: InetAddress, int: int): ...
    @staticmethod
    def createUnresolved(string: str, int: int) -> 'InetSocketAddress': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getAddress(self) -> InetAddress: ...
    def getHostName(self) -> str: ...
    def getHostString(self) -> str: ...
    def getPort(self) -> int: ...
    def hashCode(self) -> int: ...
    def isUnresolved(self) -> bool: ...
    def toString(self) -> str: ...

class JarURLConnection(URLConnection):
    def getAttributes(self) -> java.util.jar.Attributes: ...
    def getCertificates(self) -> typing.List[java.security.cert.Certificate]: ...
    def getEntryName(self) -> str: ...
    def getJarEntry(self) -> java.util.jar.JarEntry: ...
    def getJarFile(self) -> java.util.jar.JarFile: ...
    def getJarFileURL(self) -> URL: ...
    def getMainAttributes(self) -> java.util.jar.Attributes: ...
    def getManifest(self) -> java.util.jar.Manifest: ...

class MulticastSocket(DatagramSocket):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, socketAddress: SocketAddress): ...
    def getInterface(self) -> InetAddress: ...
    def getLoopbackMode(self) -> bool: ...
    def getNetworkInterface(self) -> NetworkInterface: ...
    def getTTL(self) -> int: ...
    def getTimeToLive(self) -> int: ...
    @typing.overload
    def joinGroup(self, inetAddress: InetAddress) -> None: ...
    @typing.overload
    def joinGroup(self, socketAddress: SocketAddress, networkInterface: NetworkInterface) -> None: ...
    @typing.overload
    def leaveGroup(self, inetAddress: InetAddress) -> None: ...
    @typing.overload
    def leaveGroup(self, socketAddress: SocketAddress, networkInterface: NetworkInterface) -> None: ...
    @typing.overload
    def send(self, datagramPacket: DatagramPacket) -> None: ...
    @typing.overload
    def send(self, datagramPacket: DatagramPacket, byte: int) -> None: ...
    def setInterface(self, inetAddress: InetAddress) -> None: ...
    def setLoopbackMode(self, boolean: bool) -> None: ...
    def setNetworkInterface(self, networkInterface: NetworkInterface) -> None: ...
    def setTTL(self, byte: int) -> None: ...
    def setTimeToLive(self, int: int) -> None: ...
    def supportedOptions(self) -> java.util.Set[SocketOption[typing.Any]]: ...

class NoRouteToHostException(SocketException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class PortUnreachableException(SocketException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class SecureCacheResponse(CacheResponse):
    def __init__(self): ...
    def getCipherSuite(self) -> str: ...
    def getLocalCertificateChain(self) -> java.util.List[java.security.cert.Certificate]: ...
    def getLocalPrincipal(self) -> java.security.Principal: ...
    def getPeerPrincipal(self) -> java.security.Principal: ...
    def getServerCertificateChain(self) -> java.util.List[java.security.cert.Certificate]: ...

class SocketImpl(SocketOptions):
    def __init__(self): ...
    def toString(self) -> str: ...

class StandardProtocolFamily(java.lang.Enum['StandardProtocolFamily'], ProtocolFamily):
    INET: typing.ClassVar['StandardProtocolFamily'] = ...
    INET6: typing.ClassVar['StandardProtocolFamily'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'StandardProtocolFamily': ...
    @staticmethod
    def values() -> typing.List['StandardProtocolFamily']: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.net")``.

    Authenticator: typing.Type[Authenticator]
    BindException: typing.Type[BindException]
    CacheRequest: typing.Type[CacheRequest]
    CacheResponse: typing.Type[CacheResponse]
    ConnectException: typing.Type[ConnectException]
    ContentHandler: typing.Type[ContentHandler]
    ContentHandlerFactory: typing.Type[ContentHandlerFactory]
    CookieHandler: typing.Type[CookieHandler]
    CookieManager: typing.Type[CookieManager]
    CookiePolicy: typing.Type[CookiePolicy]
    CookieStore: typing.Type[CookieStore]
    DatagramPacket: typing.Type[DatagramPacket]
    DatagramSocket: typing.Type[DatagramSocket]
    DatagramSocketImpl: typing.Type[DatagramSocketImpl]
    DatagramSocketImplFactory: typing.Type[DatagramSocketImplFactory]
    FileNameMap: typing.Type[FileNameMap]
    HttpCookie: typing.Type[HttpCookie]
    HttpRetryException: typing.Type[HttpRetryException]
    HttpURLConnection: typing.Type[HttpURLConnection]
    IDN: typing.Type[IDN]
    Inet4Address: typing.Type[Inet4Address]
    Inet6Address: typing.Type[Inet6Address]
    InetAddress: typing.Type[InetAddress]
    InetSocketAddress: typing.Type[InetSocketAddress]
    InterfaceAddress: typing.Type[InterfaceAddress]
    JarURLConnection: typing.Type[JarURLConnection]
    MalformedURLException: typing.Type[MalformedURLException]
    MulticastSocket: typing.Type[MulticastSocket]
    NetPermission: typing.Type[NetPermission]
    NetworkInterface: typing.Type[NetworkInterface]
    NoRouteToHostException: typing.Type[NoRouteToHostException]
    PasswordAuthentication: typing.Type[PasswordAuthentication]
    PortUnreachableException: typing.Type[PortUnreachableException]
    ProtocolException: typing.Type[ProtocolException]
    ProtocolFamily: typing.Type[ProtocolFamily]
    Proxy: typing.Type[Proxy]
    ProxySelector: typing.Type[ProxySelector]
    ResponseCache: typing.Type[ResponseCache]
    SecureCacheResponse: typing.Type[SecureCacheResponse]
    ServerSocket: typing.Type[ServerSocket]
    Socket: typing.Type[Socket]
    SocketAddress: typing.Type[SocketAddress]
    SocketException: typing.Type[SocketException]
    SocketImpl: typing.Type[SocketImpl]
    SocketImplFactory: typing.Type[SocketImplFactory]
    SocketOption: typing.Type[SocketOption]
    SocketOptions: typing.Type[SocketOptions]
    SocketPermission: typing.Type[SocketPermission]
    SocketTimeoutException: typing.Type[SocketTimeoutException]
    StandardProtocolFamily: typing.Type[StandardProtocolFamily]
    StandardSocketOptions: typing.Type[StandardSocketOptions]
    URI: typing.Type[URI]
    URISyntaxException: typing.Type[URISyntaxException]
    URL: typing.Type[URL]
    URLClassLoader: typing.Type[URLClassLoader]
    URLConnection: typing.Type[URLConnection]
    URLDecoder: typing.Type[URLDecoder]
    URLEncoder: typing.Type[URLEncoder]
    URLPermission: typing.Type[URLPermission]
    URLStreamHandler: typing.Type[URLStreamHandler]
    URLStreamHandlerFactory: typing.Type[URLStreamHandlerFactory]
    UnknownHostException: typing.Type[UnknownHostException]
    UnknownServiceException: typing.Type[UnknownServiceException]
    http: java.net.http.__module_protocol__
    spi: java.net.spi.__module_protocol__



import java.lang
import org.bitbucket.inkytonik.kiama.attribution
import org.bitbucket.inkytonik.kiama.rewriting
import org.ergoplatform
import org.ergoplatform.wallet.protocol.context
import org.ergoplatform.wallet.secrets
import scala
import scala.collection
import scala.collection.immutable
import scala.util
import sigmastate
import sigmastate.basics
import sigmastate.eval
import sigmastate.interpreter
import typing



class ErgoInterpreter(org.ergoplatform.ErgoLikeInterpreter):
    def __init__(self, params: org.ergoplatform.wallet.protocol.context.ErgoLikeParameters, IR: sigmastate.eval.IRContext): ...
    @staticmethod
    def apply(params: org.ergoplatform.wallet.protocol.context.ErgoLikeParameters) -> 'ErgoInterpreter': ...
    @staticmethod
    def avlTreeFromDigest(digest: typing.List[int]) -> sigmastate.AvlTreeData: ...
    def checkExpiredBox(self, box: org.ergoplatform.ErgoBox, output: org.ergoplatform.ErgoBoxCandidate, currentHeight: int) -> bool: ...
    @staticmethod
    def frequentlyUsedScripts() -> scala.collection.Seq[java.lang.String]: ...
    @staticmethod
    def scriptProcessor() -> sigmastate.interpreter.PrecompiledScriptProcessor: ...
    @typing.overload
    def verify(self, env: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any], ergoTree: sigmastate.Values.ErgoTree, context: sigmastate.interpreter.InterpreterContext, proverResult: sigmastate.interpreter.ProverResult, message: typing.List[int]) -> scala.util.Try[scala.Tuple2[typing.Any, typing.Any]]: ...
    @typing.overload
    def verify(self, ergoTree: sigmastate.Values.ErgoTree, context: sigmastate.interpreter.InterpreterContext, proof: sigmastate.UncheckedTree, message: typing.List[int]) -> scala.util.Try[scala.Tuple2[typing.Any, typing.Any]]: ...
    @typing.overload
    def verify(self, ergoTree: sigmastate.Values.ErgoTree, context: sigmastate.interpreter.InterpreterContext, proverResult: sigmastate.interpreter.ProverResult, message: typing.List[int]) -> scala.util.Try[scala.Tuple2[typing.Any, typing.Any]]: ...
    @typing.overload
    def verify(self, env: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any], exp: sigmastate.Values.ErgoTree, context: org.ergoplatform.ErgoLikeContext, proof: typing.List[int], message: typing.List[int]) -> scala.util.Try[scala.Tuple2[typing.Any, typing.Any]]: ...

class ErgoUnsafeProver:
    @typing.overload
    @staticmethod
    def prove(unsignedTx: org.ergoplatform.UnsignedErgoLikeTransaction, sks: scala.collection.Map[typing.Union[java.lang.String, str], sigmastate.basics.DLogProtocol.DLogProverInput]) -> org.ergoplatform.ErgoLikeTransaction: ...
    @typing.overload
    @staticmethod
    def prove(unsignedTx: org.ergoplatform.UnsignedErgoLikeTransaction, sk: sigmastate.basics.DLogProtocol.DLogProverInput) -> org.ergoplatform.ErgoLikeTransaction: ...

class TransactionHintsBag(scala.Product, scala.Serializable):
    def __init__(self, secretHints: scala.collection.immutable.Map[typing.Any, sigmastate.interpreter.HintsBag], publicHints: scala.collection.immutable.Map[typing.Any, sigmastate.interpreter.HintsBag]): ...
    def addHintsForInput(self, index: int, hintsBag: sigmastate.interpreter.HintsBag) -> 'TransactionHintsBag': ...
    def allHintsForInput(self, index: int) -> sigmastate.interpreter.HintsBag: ...
    @typing.overload
    @staticmethod
    def apply(mixedHints: scala.collection.immutable.Map[typing.Any, sigmastate.interpreter.HintsBag]) -> 'TransactionHintsBag': ...
    @typing.overload
    @staticmethod
    def apply(secretHints: scala.collection.immutable.Map[typing.Any, sigmastate.interpreter.HintsBag], publicHints: scala.collection.immutable.Map[typing.Any, sigmastate.interpreter.HintsBag]) -> 'TransactionHintsBag': ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def copy(self, secretHints: scala.collection.immutable.Map[typing.Any, sigmastate.interpreter.HintsBag], publicHints: scala.collection.immutable.Map[typing.Any, sigmastate.interpreter.HintsBag]) -> 'TransactionHintsBag': ...
    def copy$default$1(self) -> scala.collection.immutable.Map[typing.Any, sigmastate.interpreter.HintsBag]: ...
    def copy$default$2(self) -> scala.collection.immutable.Map[typing.Any, sigmastate.interpreter.HintsBag]: ...
    @staticmethod
    def empty() -> 'TransactionHintsBag': ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def publicHints(self) -> scala.collection.immutable.Map[typing.Any, sigmastate.interpreter.HintsBag]: ...
    def replaceHintsForInput(self, index: int, hintsBag: sigmastate.interpreter.HintsBag) -> 'TransactionHintsBag': ...
    def secretHints(self) -> scala.collection.immutable.Map[typing.Any, sigmastate.interpreter.HintsBag]: ...
    def toString(self) -> java.lang.String: ...
    @staticmethod
    def unapply(x$0: 'TransactionHintsBag') -> scala.Option[scala.Tuple2[scala.collection.immutable.Map[typing.Any, sigmastate.interpreter.HintsBag], scala.collection.immutable.Map[typing.Any, sigmastate.interpreter.HintsBag]]]: ...

class ErgoProvingInterpreter(ErgoInterpreter, sigmastate.interpreter.ProverInterpreter):
    def __init__(self, secretKeys: scala.collection.IndexedSeq[org.ergoplatform.wallet.secrets.SecretKey], params: org.ergoplatform.wallet.protocol.context.ErgoLikeParameters, cachedHdPubKeysOpt: scala.Option[scala.collection.IndexedSeq[org.ergoplatform.wallet.secrets.ExtendedPublicKey]], IR: sigmastate.eval.IRContext): ...
    @staticmethod
    def $lessinit$greater$default$3() -> scala.Option[scala.collection.IndexedSeq[org.ergoplatform.wallet.secrets.ExtendedPublicKey]]: ...
    def activatedScriptVersion(self) -> int: ...
    @typing.overload
    @staticmethod
    def apply(params: org.ergoplatform.wallet.protocol.context.ErgoLikeParameters) -> ErgoInterpreter: ...
    @typing.overload
    @staticmethod
    def apply(rootSecret: org.ergoplatform.wallet.secrets.ExtendedSecretKey, params: org.ergoplatform.wallet.protocol.context.ErgoLikeParameters) -> 'ErgoProvingInterpreter': ...
    @typing.overload
    @staticmethod
    def apply(secrets: scala.collection.IndexedSeq[org.ergoplatform.wallet.secrets.SecretKey], params: org.ergoplatform.wallet.protocol.context.ErgoLikeParameters) -> 'ErgoProvingInterpreter': ...
    _attrWithName__T = typing.TypeVar('_attrWithName__T')  # <T>
    _attrWithName__U = typing.TypeVar('_attrWithName__U')  # <U>
    def attrWithName(self, name: typing.Union[java.lang.String, str], f: scala.Function1[_attrWithName__T, _attrWithName__U]) -> org.bitbucket.inkytonik.kiama.attribution.AttributionCore.CachedAttribute[_attrWithName__T, _attrWithName__U]: ...
    @typing.overload
    def bagForMultisig(self, context: sigmastate.interpreter.InterpreterContext, ergoTree: sigmastate.Values.ErgoTree, proof: typing.List[int], realSecretsToExtract: scala.collection.Seq[sigmastate.Values.SigmaBoolean], simulatedSecretsToExtract: scala.collection.Seq[sigmastate.Values.SigmaBoolean]) -> sigmastate.interpreter.HintsBag: ...
    @typing.overload
    def bagForMultisig(self, context: sigmastate.interpreter.InterpreterContext, sigmaTree: sigmastate.Values.SigmaBoolean, proof: typing.List[int], realSecretsToExtract: scala.collection.Seq[sigmastate.Values.SigmaBoolean], simulatedSecretsToExtract: scala.collection.Seq[sigmastate.Values.SigmaBoolean]) -> sigmastate.interpreter.HintsBag: ...
    def bagForMultisig$default$5(self) -> scala.collection.Seq[sigmastate.Values.SigmaBoolean]: ...
    def bagForTransaction(self, tx: org.ergoplatform.ErgoLikeTransaction, boxesToSpend: scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], dataBoxes: scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], stateContext: org.ergoplatform.wallet.protocol.context.ErgoLikeStateContext, realSecretsToExtract: scala.collection.Seq[sigmastate.Values.SigmaBoolean], simulatedSecretsToExtract: scala.collection.Seq[sigmastate.Values.SigmaBoolean]) -> TransactionHintsBag: ...
    def cachedHdPubKeysOpt(self) -> scala.Option[scala.collection.IndexedSeq[org.ergoplatform.wallet.secrets.ExtendedPublicKey]]: ...
    _circularWithName__T = typing.TypeVar('_circularWithName__T')  # <T>
    _circularWithName__U = typing.TypeVar('_circularWithName__U')  # <U>
    def circularWithName(self, name: typing.Union[java.lang.String, str], init: _circularWithName__U, f: scala.Function1[_circularWithName__T, _circularWithName__U]) -> org.bitbucket.inkytonik.kiama.attribution.AttributionCore.CircularAttribute[_circularWithName__T, _circularWithName__U]: ...
    _constant__T = typing.TypeVar('_constant__T')  # <T>
    _constant__U = typing.TypeVar('_constant__U')  # <U>
    def constant(self, name: typing.Union[java.lang.String, str], u: scala.Function0[_constant__U]) -> org.bitbucket.inkytonik.kiama.attribution.Attribute[_constant__T, _constant__U]: ...
    def convertToUnchecked(self) -> scala.Function1[sigmastate.ProofTree, sigmastate.UncheckedSigmaTree]: ...
    def convertToUnproven(self, sigmaTree: sigmastate.Values.SigmaBoolean) -> sigmastate.UnprovenTree: ...
    _dynAttrWithName__T = typing.TypeVar('_dynAttrWithName__T')  # <T>
    _dynAttrWithName__U = typing.TypeVar('_dynAttrWithName__U')  # <U>
    def dynAttrWithName(self, name: typing.Union[java.lang.String, str], f: scala.Function1[_dynAttrWithName__T, _dynAttrWithName__U]) -> org.bitbucket.inkytonik.kiama.attribution.AttributionCore.CachedDynamicAttribute[_dynAttrWithName__T, _dynAttrWithName__U]: ...
    @typing.overload
    def generateCommitments(self, ergoTree: sigmastate.Values.ErgoTree, ctx: sigmastate.interpreter.InterpreterContext) -> sigmastate.interpreter.HintsBag: ...
    @typing.overload
    def generateCommitments(self, sigmaTree: sigmastate.Values.SigmaBoolean) -> sigmastate.interpreter.HintsBag: ...
    @typing.overload
    def generateCommitmentsFor(self, unsignedTx: org.ergoplatform.UnsignedErgoLikeTransaction, boxesToSpend: scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], dataBoxes: scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], stateContext: org.ergoplatform.wallet.protocol.context.ErgoLikeStateContext) -> scala.util.Try[TransactionHintsBag]: ...
    @typing.overload
    def generateCommitmentsFor(self, ergoTree: sigmastate.Values.ErgoTree, context: sigmastate.interpreter.InterpreterContext, generateFor: scala.collection.Seq[sigmastate.Values.SigmaBoolean]) -> sigmastate.interpreter.HintsBag: ...
    @typing.overload
    def generateCommitmentsFor(self, sigmaTree: sigmastate.Values.SigmaBoolean, generateFor: scala.collection.Seq[sigmastate.Values.SigmaBoolean]) -> sigmastate.interpreter.HintsBag: ...
    def generateProof(self, sb: sigmastate.Values.SigmaBoolean, message: typing.List[int], hintsBag: sigmastate.interpreter.HintsBag) -> typing.List[int]: ...
    def hdKeys(self) -> scala.collection.IndexedSeq[org.ergoplatform.wallet.secrets.ExtendedSecretKey]: ...
    def hdPubKeys(self) -> scala.collection.IndexedSeq[org.ergoplatform.wallet.secrets.ExtendedPublicKey]: ...
    _internalToDynamicAttribute__T = typing.TypeVar('_internalToDynamicAttribute__T')  # <T>
    _internalToDynamicAttribute__U = typing.TypeVar('_internalToDynamicAttribute__U')  # <U>
    def internalToDynamicAttribute(self, f: scala.Function1[_internalToDynamicAttribute__T, _internalToDynamicAttribute__U]) -> org.bitbucket.inkytonik.kiama.attribution.AttributionCore.CachedDynamicAttribute[_internalToDynamicAttribute__T, _internalToDynamicAttribute__U]: ...
    def markReal(self, hintsBag: sigmastate.interpreter.HintsBag) -> org.bitbucket.inkytonik.kiama.rewriting.Strategy: ...
    def org$bitbucket$inkytonik$kiama$attribution$AttributionCore$$CircularAttribute(self) -> org.bitbucket.inkytonik.kiama.attribution.AttributionCore.CircularAttribute.: ...
    _paramAttrWithName__V = typing.TypeVar('_paramAttrWithName__V')  # <V>
    _paramAttrWithName__T = typing.TypeVar('_paramAttrWithName__T')  # <T>
    _paramAttrWithName__U = typing.TypeVar('_paramAttrWithName__U')  # <U>
    def paramAttrWithName(self, name: typing.Union[java.lang.String, str], f: scala.Function1[_paramAttrWithName__V, scala.Function1[_paramAttrWithName__T, _paramAttrWithName__U]]) -> org.bitbucket.inkytonik.kiama.attribution.AttributionCore.CachedParamAttribute[_paramAttrWithName__V, _paramAttrWithName__T, _paramAttrWithName__U]: ...
    def polishSimulated(self) -> org.bitbucket.inkytonik.kiama.rewriting.Strategy: ...
    @typing.overload
    def prove(self, env: scala.collection.immutable.Map[typing.Union[java.lang.String, str], typing.Any], ergoTree: sigmastate.Values.ErgoTree, context: sigmastate.interpreter.InterpreterContext, message: typing.List[int], hintsBag: sigmastate.interpreter.HintsBag) -> scala.util.Try[sigmastate.interpreter.CostedProverResult]: ...
    @typing.overload
    def prove(self, ergoTree: sigmastate.Values.ErgoTree, context: sigmastate.interpreter.InterpreterContext, message: typing.List[int]) -> scala.util.Try[sigmastate.interpreter.CostedProverResult]: ...
    @typing.overload
    def prove(self, ergoTree: sigmastate.Values.ErgoTree, context: sigmastate.interpreter.InterpreterContext, message: typing.List[int], hintsBag: sigmastate.interpreter.HintsBag) -> scala.util.Try[sigmastate.interpreter.CostedProverResult]: ...
    @typing.overload
    def prove(self, unprovenTree: sigmastate.UnprovenTree, message: typing.List[int], hintsBag: sigmastate.interpreter.HintsBag) -> sigmastate.UncheckedTree: ...
    def prove$default$5(self) -> sigmastate.interpreter.HintsBag: ...
    def proving(self, hintsBag: sigmastate.interpreter.HintsBag) -> org.bitbucket.inkytonik.kiama.rewriting.Strategy: ...
    def publicKeys(self) -> scala.collection.Seq[sigmastate.Values.SigmaBoolean]: ...
    def secretKeys(self) -> scala.collection.IndexedSeq[org.ergoplatform.wallet.secrets.SecretKey]: ...
    def secrets(self) -> scala.collection.IndexedSeq[sigmastate.basics.SigmaProtocolPrivateInput[typing.Any, typing.Any]]: ...
    def setPositions(self, uc: sigmastate.UnprovenConjecture) -> sigmastate.UnprovenConjecture: ...
    def sigmastate$interpreter$ProverInterpreter$_setter_$convertToUnchecked_$eq(self, x$1: scala.Function1[sigmastate.ProofTree, sigmastate.UncheckedSigmaTree]) -> None: ...
    def sigmastate$interpreter$ProverInterpreter$_setter_$polishSimulated_$eq(self, x$1: org.bitbucket.inkytonik.kiama.rewriting.Strategy) -> None: ...
    def sign(self, unsignedTx: org.ergoplatform.UnsignedErgoLikeTransaction, boxesToSpend: scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], dataBoxes: scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], stateContext: org.ergoplatform.wallet.protocol.context.ErgoLikeStateContext, txHints: TransactionHintsBag) -> scala.util.Try[org.ergoplatform.ErgoLikeTransaction]: ...
    def sign$default$5(self) -> TransactionHintsBag: ...
    def signInputs(self, unsignedTx: org.ergoplatform.UnsignedErgoLikeTransaction, boxesToSpend: scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], dataBoxes: scala.collection.IndexedSeq[org.ergoplatform.ErgoBox], stateContext: org.ergoplatform.wallet.protocol.context.ErgoLikeStateContext, txHints: TransactionHintsBag) -> scala.util.Try[scala.Tuple2[scala.collection.IndexedSeq[org.ergoplatform.Input], typing.Any]]: ...
    def signMessage(self, sigmaTree: sigmastate.Values.SigmaBoolean, message: typing.List[int], hintsBag: sigmastate.interpreter.HintsBag) -> scala.util.Try[typing.List[int]]: ...
    def simulateAndCommit(self, hintsBag: sigmastate.interpreter.HintsBag) -> org.bitbucket.inkytonik.kiama.rewriting.Strategy: ...
    def withNewExtendedSecret(self, secret: org.ergoplatform.wallet.secrets.ExtendedSecretKey) -> 'ErgoProvingInterpreter': ...
    def withNewParameters(self, newParams: org.ergoplatform.wallet.protocol.context.ErgoLikeParameters) -> 'ErgoProvingInterpreter': ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.wallet.interpreter")``.

    ErgoInterpreter: typing.Type[ErgoInterpreter]
    ErgoProvingInterpreter: typing.Type[ErgoProvingInterpreter]
    ErgoUnsafeProver: typing.Type[ErgoUnsafeProver]
    TransactionHintsBag: typing.Type[TransactionHintsBag]



import scorex.util.encode
import typing



class package:
    @staticmethod
    def Base16() -> scorex.util.encode.Base16.: ...
    @staticmethod
    def Base58() -> scorex.util.encode.Base58.: ...
    @staticmethod
    def Base64() -> scorex.util.encode.Base64.: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scorex.crypto.encode")``.

    package: typing.Type[package]



import java.lang
import java.security
import java.util
import javax.management
import typing



class LockInfo:
    def __init__(self, string: str, int: int): ...
    def getClassName(self) -> str: ...
    def getIdentityHashCode(self) -> int: ...
    def toString(self) -> str: ...

class ManagementFactory:
    CLASS_LOADING_MXBEAN_NAME: typing.ClassVar[str] = ...
    COMPILATION_MXBEAN_NAME: typing.ClassVar[str] = ...
    MEMORY_MXBEAN_NAME: typing.ClassVar[str] = ...
    OPERATING_SYSTEM_MXBEAN_NAME: typing.ClassVar[str] = ...
    RUNTIME_MXBEAN_NAME: typing.ClassVar[str] = ...
    THREAD_MXBEAN_NAME: typing.ClassVar[str] = ...
    GARBAGE_COLLECTOR_MXBEAN_DOMAIN_TYPE: typing.ClassVar[str] = ...
    MEMORY_MANAGER_MXBEAN_DOMAIN_TYPE: typing.ClassVar[str] = ...
    MEMORY_POOL_MXBEAN_DOMAIN_TYPE: typing.ClassVar[str] = ...
    @staticmethod
    def getClassLoadingMXBean() -> 'ClassLoadingMXBean': ...
    @staticmethod
    def getCompilationMXBean() -> 'CompilationMXBean': ...
    @staticmethod
    def getGarbageCollectorMXBeans() -> java.util.List['GarbageCollectorMXBean']: ...
    @staticmethod
    def getMemoryMXBean() -> 'MemoryMXBean': ...
    @staticmethod
    def getMemoryManagerMXBeans() -> java.util.List['MemoryManagerMXBean']: ...
    @staticmethod
    def getMemoryPoolMXBeans() -> java.util.List['MemoryPoolMXBean']: ...
    @staticmethod
    def getOperatingSystemMXBean() -> 'OperatingSystemMXBean': ...
    @staticmethod
    def getPlatformMBeanServer() -> javax.management.MBeanServer: ...
    _getPlatformMXBean_0__T = typing.TypeVar('_getPlatformMXBean_0__T', bound='PlatformManagedObject')  # <T>
    _getPlatformMXBean_1__T = typing.TypeVar('_getPlatformMXBean_1__T', bound='PlatformManagedObject')  # <T>
    @typing.overload
    @staticmethod
    def getPlatformMXBean(class_: typing.Type[_getPlatformMXBean_0__T]) -> _getPlatformMXBean_0__T: ...
    @typing.overload
    @staticmethod
    def getPlatformMXBean(mBeanServerConnection: javax.management.MBeanServerConnection, class_: typing.Type[_getPlatformMXBean_1__T]) -> _getPlatformMXBean_1__T: ...
    _getPlatformMXBeans_0__T = typing.TypeVar('_getPlatformMXBeans_0__T', bound='PlatformManagedObject')  # <T>
    _getPlatformMXBeans_1__T = typing.TypeVar('_getPlatformMXBeans_1__T', bound='PlatformManagedObject')  # <T>
    @typing.overload
    @staticmethod
    def getPlatformMXBeans(class_: typing.Type[_getPlatformMXBeans_0__T]) -> java.util.List[_getPlatformMXBeans_0__T]: ...
    @typing.overload
    @staticmethod
    def getPlatformMXBeans(mBeanServerConnection: javax.management.MBeanServerConnection, class_: typing.Type[_getPlatformMXBeans_1__T]) -> java.util.List[_getPlatformMXBeans_1__T]: ...
    @staticmethod
    def getPlatformManagementInterfaces() -> java.util.Set[typing.Type['PlatformManagedObject']]: ...
    @staticmethod
    def getRuntimeMXBean() -> 'RuntimeMXBean': ...
    @staticmethod
    def getThreadMXBean() -> 'ThreadMXBean': ...
    _newPlatformMXBeanProxy__T = typing.TypeVar('_newPlatformMXBeanProxy__T')  # <T>
    @staticmethod
    def newPlatformMXBeanProxy(mBeanServerConnection: javax.management.MBeanServerConnection, string: str, class_: typing.Type[_newPlatformMXBeanProxy__T]) -> _newPlatformMXBeanProxy__T: ...

class ManagementPermission(java.security.BasicPermission):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str): ...

class MemoryNotificationInfo:
    MEMORY_THRESHOLD_EXCEEDED: typing.ClassVar[str] = ...
    MEMORY_COLLECTION_THRESHOLD_EXCEEDED: typing.ClassVar[str] = ...
    def __init__(self, string: str, memoryUsage: 'MemoryUsage', long: int): ...
    def getCount(self) -> int: ...
    def getPoolName(self) -> str: ...
    def getUsage(self) -> 'MemoryUsage': ...

class MemoryType(java.lang.Enum['MemoryType']):
    HEAP: typing.ClassVar['MemoryType'] = ...
    NON_HEAP: typing.ClassVar['MemoryType'] = ...
    def toString(self) -> str: ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'MemoryType': ...
    @staticmethod
    def values() -> typing.List['MemoryType']: ...

class MemoryUsage:
    def __init__(self, long: int, long2: int, long3: int, long4: int): ...
    def getCommitted(self) -> int: ...
    def getInit(self) -> int: ...
    def getMax(self) -> int: ...
    def getUsed(self) -> int: ...
    def toString(self) -> str: ...

class PlatformManagedObject:
    def getObjectName(self) -> javax.management.ObjectName: ...

class ThreadInfo:
    def getBlockedCount(self) -> int: ...
    def getBlockedTime(self) -> int: ...
    def getLockInfo(self) -> LockInfo: ...
    def getLockName(self) -> str: ...
    def getLockOwnerId(self) -> int: ...
    def getLockOwnerName(self) -> str: ...
    def getLockedMonitors(self) -> typing.List['MonitorInfo']: ...
    def getLockedSynchronizers(self) -> typing.List[LockInfo]: ...
    def getPriority(self) -> int: ...
    def getStackTrace(self) -> typing.List[java.lang.StackTraceElement]: ...
    def getThreadId(self) -> int: ...
    def getThreadName(self) -> str: ...
    def getThreadState(self) -> java.lang.Thread.State: ...
    def getWaitedCount(self) -> int: ...
    def getWaitedTime(self) -> int: ...
    def isDaemon(self) -> bool: ...
    def isInNative(self) -> bool: ...
    def isSuspended(self) -> bool: ...
    def toString(self) -> str: ...

class BufferPoolMXBean(PlatformManagedObject):
    def getCount(self) -> int: ...
    def getMemoryUsed(self) -> int: ...
    def getName(self) -> str: ...
    def getTotalCapacity(self) -> int: ...

class ClassLoadingMXBean(PlatformManagedObject):
    def getLoadedClassCount(self) -> int: ...
    def getTotalLoadedClassCount(self) -> int: ...
    def getUnloadedClassCount(self) -> int: ...
    def isVerbose(self) -> bool: ...
    def setVerbose(self, boolean: bool) -> None: ...

class CompilationMXBean(PlatformManagedObject):
    def getName(self) -> str: ...
    def getTotalCompilationTime(self) -> int: ...
    def isCompilationTimeMonitoringSupported(self) -> bool: ...

class MemoryMXBean(PlatformManagedObject):
    def gc(self) -> None: ...
    def getHeapMemoryUsage(self) -> MemoryUsage: ...
    def getNonHeapMemoryUsage(self) -> MemoryUsage: ...
    def getObjectPendingFinalizationCount(self) -> int: ...
    def isVerbose(self) -> bool: ...
    def setVerbose(self, boolean: bool) -> None: ...

class MemoryManagerMXBean(PlatformManagedObject):
    def getMemoryPoolNames(self) -> typing.List[str]: ...
    def getName(self) -> str: ...
    def isValid(self) -> bool: ...

class MemoryPoolMXBean(PlatformManagedObject):
    def getCollectionUsage(self) -> MemoryUsage: ...
    def getCollectionUsageThreshold(self) -> int: ...
    def getCollectionUsageThresholdCount(self) -> int: ...
    def getMemoryManagerNames(self) -> typing.List[str]: ...
    def getName(self) -> str: ...
    def getPeakUsage(self) -> MemoryUsage: ...
    def getType(self) -> MemoryType: ...
    def getUsage(self) -> MemoryUsage: ...
    def getUsageThreshold(self) -> int: ...
    def getUsageThresholdCount(self) -> int: ...
    def isCollectionUsageThresholdExceeded(self) -> bool: ...
    def isCollectionUsageThresholdSupported(self) -> bool: ...
    def isUsageThresholdExceeded(self) -> bool: ...
    def isUsageThresholdSupported(self) -> bool: ...
    def isValid(self) -> bool: ...
    def resetPeakUsage(self) -> None: ...
    def setCollectionUsageThreshold(self, long: int) -> None: ...
    def setUsageThreshold(self, long: int) -> None: ...

class MonitorInfo(LockInfo):
    def __init__(self, string: str, int: int, int2: int, stackTraceElement: java.lang.StackTraceElement): ...
    def getLockedStackDepth(self) -> int: ...
    def getLockedStackFrame(self) -> java.lang.StackTraceElement: ...

class OperatingSystemMXBean(PlatformManagedObject):
    def getArch(self) -> str: ...
    def getAvailableProcessors(self) -> int: ...
    def getName(self) -> str: ...
    def getSystemLoadAverage(self) -> float: ...
    def getVersion(self) -> str: ...

class PlatformLoggingMXBean(PlatformManagedObject):
    def getLoggerLevel(self, string: str) -> str: ...
    def getLoggerNames(self) -> java.util.List[str]: ...
    def getParentLoggerName(self, string: str) -> str: ...
    def setLoggerLevel(self, string: str, string2: str) -> None: ...

class RuntimeMXBean(PlatformManagedObject):
    def getBootClassPath(self) -> str: ...
    def getClassPath(self) -> str: ...
    def getInputArguments(self) -> java.util.List[str]: ...
    def getLibraryPath(self) -> str: ...
    def getManagementSpecVersion(self) -> str: ...
    def getName(self) -> str: ...
    def getPid(self) -> int: ...
    def getSpecName(self) -> str: ...
    def getSpecVendor(self) -> str: ...
    def getSpecVersion(self) -> str: ...
    def getStartTime(self) -> int: ...
    def getSystemProperties(self) -> java.util.Map[str, str]: ...
    def getUptime(self) -> int: ...
    def getVmName(self) -> str: ...
    def getVmVendor(self) -> str: ...
    def getVmVersion(self) -> str: ...
    def isBootClassPathSupported(self) -> bool: ...

class ThreadMXBean(PlatformManagedObject):
    @typing.overload
    def dumpAllThreads(self, boolean: bool, boolean2: bool) -> typing.List[ThreadInfo]: ...
    @typing.overload
    def dumpAllThreads(self, boolean: bool, boolean2: bool, int: int) -> typing.List[ThreadInfo]: ...
    def findDeadlockedThreads(self) -> typing.List[int]: ...
    def findMonitorDeadlockedThreads(self) -> typing.List[int]: ...
    def getAllThreadIds(self) -> typing.List[int]: ...
    def getCurrentThreadCpuTime(self) -> int: ...
    def getCurrentThreadUserTime(self) -> int: ...
    def getDaemonThreadCount(self) -> int: ...
    def getPeakThreadCount(self) -> int: ...
    def getThreadCount(self) -> int: ...
    def getThreadCpuTime(self, long: int) -> int: ...
    @typing.overload
    def getThreadInfo(self, long: int) -> ThreadInfo: ...
    @typing.overload
    def getThreadInfo(self, long: int, int: int) -> ThreadInfo: ...
    @typing.overload
    def getThreadInfo(self, longArray: typing.List[int]) -> typing.List[ThreadInfo]: ...
    @typing.overload
    def getThreadInfo(self, longArray: typing.List[int], boolean: bool, boolean2: bool) -> typing.List[ThreadInfo]: ...
    @typing.overload
    def getThreadInfo(self, longArray: typing.List[int], int: int) -> typing.List[ThreadInfo]: ...
    @typing.overload
    def getThreadInfo(self, longArray: typing.List[int], boolean: bool, boolean2: bool, int: int) -> typing.List[ThreadInfo]: ...
    def getThreadUserTime(self, long: int) -> int: ...
    def getTotalStartedThreadCount(self) -> int: ...
    def isCurrentThreadCpuTimeSupported(self) -> bool: ...
    def isObjectMonitorUsageSupported(self) -> bool: ...
    def isSynchronizerUsageSupported(self) -> bool: ...
    def isThreadContentionMonitoringEnabled(self) -> bool: ...
    def isThreadContentionMonitoringSupported(self) -> bool: ...
    def isThreadCpuTimeEnabled(self) -> bool: ...
    def isThreadCpuTimeSupported(self) -> bool: ...
    def resetPeakThreadCount(self) -> None: ...
    def setThreadContentionMonitoringEnabled(self, boolean: bool) -> None: ...
    def setThreadCpuTimeEnabled(self, boolean: bool) -> None: ...

class GarbageCollectorMXBean(MemoryManagerMXBean):
    def getCollectionCount(self) -> int: ...
    def getCollectionTime(self) -> int: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.lang.management")``.

    BufferPoolMXBean: typing.Type[BufferPoolMXBean]
    ClassLoadingMXBean: typing.Type[ClassLoadingMXBean]
    CompilationMXBean: typing.Type[CompilationMXBean]
    GarbageCollectorMXBean: typing.Type[GarbageCollectorMXBean]
    LockInfo: typing.Type[LockInfo]
    ManagementFactory: typing.Type[ManagementFactory]
    ManagementPermission: typing.Type[ManagementPermission]
    MemoryMXBean: typing.Type[MemoryMXBean]
    MemoryManagerMXBean: typing.Type[MemoryManagerMXBean]
    MemoryNotificationInfo: typing.Type[MemoryNotificationInfo]
    MemoryPoolMXBean: typing.Type[MemoryPoolMXBean]
    MemoryType: typing.Type[MemoryType]
    MemoryUsage: typing.Type[MemoryUsage]
    MonitorInfo: typing.Type[MonitorInfo]
    OperatingSystemMXBean: typing.Type[OperatingSystemMXBean]
    PlatformLoggingMXBean: typing.Type[PlatformLoggingMXBean]
    PlatformManagedObject: typing.Type[PlatformManagedObject]
    RuntimeMXBean: typing.Type[RuntimeMXBean]
    ThreadInfo: typing.Type[ThreadInfo]
    ThreadMXBean: typing.Type[ThreadMXBean]



import java.lang
import java.util
import typing



class AdditionalRegister:
    serializedValue: java.lang.String = ...
    sigmaType: java.lang.String = ...
    renderedValue: java.lang.String = ...
    def __init__(self): ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> java.lang.String: ...

class AdditionalRegisters(java.util.HashMap[java.lang.String, AdditionalRegister]):
    def __init__(self): ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> java.lang.String: ...

class AdditionalRegisters1(java.util.HashMap[java.lang.String, java.lang.String]):
    def __init__(self): ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> java.lang.String: ...

class AssetInfo:
    def __init__(self): ...
    def amount(self, long: int) -> 'AssetInfo': ...
    def boxId(self, string: typing.Union[java.lang.String, str]) -> 'AssetInfo': ...
    def decimals(self, integer: int) -> 'AssetInfo': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getAmount(self) -> int: ...
    def getBoxId(self) -> java.lang.String: ...
    def getDecimals(self) -> int: ...
    def getHeaderId(self) -> java.lang.String: ...
    def getIndex(self) -> int: ...
    def getName(self) -> java.lang.String: ...
    def getTokenId(self) -> java.lang.String: ...
    def getType(self) -> java.lang.String: ...
    def hashCode(self) -> int: ...
    def headerId(self, string: typing.Union[java.lang.String, str]) -> 'AssetInfo': ...
    def index(self, integer: int) -> 'AssetInfo': ...
    def name(self, string: typing.Union[java.lang.String, str]) -> 'AssetInfo': ...
    def setAmount(self, long: int) -> None: ...
    def setBoxId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setDecimals(self, integer: int) -> None: ...
    def setHeaderId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setIndex(self, integer: int) -> None: ...
    def setName(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setTokenId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setType(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def toString(self) -> java.lang.String: ...
    def tokenId(self, string: typing.Union[java.lang.String, str]) -> 'AssetInfo': ...
    def type(self, string: typing.Union[java.lang.String, str]) -> 'AssetInfo': ...

class AssetInstanceInfo:
    def __init__(self): ...
    def amount(self, long: int) -> 'AssetInstanceInfo': ...
    def decimals(self, integer: int) -> 'AssetInstanceInfo': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getAmount(self) -> int: ...
    def getDecimals(self) -> int: ...
    def getIndex(self) -> int: ...
    def getName(self) -> java.lang.String: ...
    def getTokenId(self) -> java.lang.String: ...
    def getType(self) -> java.lang.String: ...
    def hashCode(self) -> int: ...
    def index(self, integer: int) -> 'AssetInstanceInfo': ...
    def name(self, string: typing.Union[java.lang.String, str]) -> 'AssetInstanceInfo': ...
    def setAmount(self, long: int) -> None: ...
    def setDecimals(self, integer: int) -> None: ...
    def setIndex(self, integer: int) -> None: ...
    def setName(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setTokenId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setType(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def toString(self) -> java.lang.String: ...
    def tokenId(self, string: typing.Union[java.lang.String, str]) -> 'AssetInstanceInfo': ...
    def type(self, string: typing.Union[java.lang.String, str]) -> 'AssetInstanceInfo': ...

class BadRequest:
    def __init__(self): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getReason(self) -> java.lang.String: ...
    def getStatus(self) -> int: ...
    def hashCode(self) -> int: ...
    def reason(self, string: typing.Union[java.lang.String, str]) -> 'BadRequest': ...
    def setReason(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setStatus(self, integer: int) -> None: ...
    def status(self, integer: int) -> 'BadRequest': ...
    def toString(self) -> java.lang.String: ...

class Balance:
    def __init__(self): ...
    def addTokensItem(self, tokenAmount: 'TokenAmount') -> 'Balance': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getNanoErgs(self) -> int: ...
    def getTokens(self) -> java.util.List['TokenAmount']: ...
    def hashCode(self) -> int: ...
    def nanoErgs(self, long: int) -> 'Balance': ...
    def setNanoErgs(self, long: int) -> None: ...
    def setTokens(self, list: java.util.List['TokenAmount']) -> None: ...
    def toString(self) -> java.lang.String: ...
    def tokens(self, list: java.util.List['TokenAmount']) -> 'Balance': ...

class BlockExtensionInfo:
    def __init__(self): ...
    def digest(self, string: typing.Union[java.lang.String, str]) -> 'BlockExtensionInfo': ...
    def equals(self, object: typing.Any) -> bool: ...
    def fields(self, fields: 'Fields') -> 'BlockExtensionInfo': ...
    def getDigest(self) -> java.lang.String: ...
    def getFields(self) -> 'Fields': ...
    def getHeaderId(self) -> java.lang.String: ...
    def hashCode(self) -> int: ...
    def headerId(self, string: typing.Union[java.lang.String, str]) -> 'BlockExtensionInfo': ...
    def setDigest(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setFields(self, fields: 'Fields') -> None: ...
    def setHeaderId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def toString(self) -> java.lang.String: ...

class BlockInfo:
    def __init__(self): ...
    def difficulty(self, long: int) -> 'BlockInfo': ...
    def epoch(self, integer: int) -> 'BlockInfo': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getDifficulty(self) -> int: ...
    def getEpoch(self) -> int: ...
    def getHeight(self) -> int: ...
    def getId(self) -> java.lang.String: ...
    def getMiner(self) -> 'MinerInfo': ...
    def getMinerReward(self) -> int: ...
    def getSize(self) -> int: ...
    def getTimestamp(self) -> int: ...
    def getTransactionsCount(self) -> int: ...
    def getVersion(self) -> int: ...
    def hashCode(self) -> int: ...
    def height(self, integer: int) -> 'BlockInfo': ...
    def id(self, string: typing.Union[java.lang.String, str]) -> 'BlockInfo': ...
    def miner(self, minerInfo: 'MinerInfo') -> 'BlockInfo': ...
    def minerReward(self, long: int) -> 'BlockInfo': ...
    def setDifficulty(self, long: int) -> None: ...
    def setEpoch(self, integer: int) -> None: ...
    def setHeight(self, integer: int) -> None: ...
    def setId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setMiner(self, minerInfo: 'MinerInfo') -> None: ...
    def setMinerReward(self, long: int) -> None: ...
    def setSize(self, integer: int) -> None: ...
    def setTimestamp(self, long: int) -> None: ...
    def setTransactionsCount(self, integer: int) -> None: ...
    def setVersion(self, integer: int) -> None: ...
    def size(self, integer: int) -> 'BlockInfo': ...
    def timestamp(self, long: int) -> 'BlockInfo': ...
    def toString(self) -> java.lang.String: ...
    def transactionsCount(self, integer: int) -> 'BlockInfo': ...
    def version(self, integer: int) -> 'BlockInfo': ...

class BlockReferencesInfo:
    def __init__(self): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getNextId(self) -> java.lang.String: ...
    def getPreviousId(self) -> java.lang.String: ...
    def hashCode(self) -> int: ...
    def nextId(self, string: typing.Union[java.lang.String, str]) -> 'BlockReferencesInfo': ...
    def previousId(self, string: typing.Union[java.lang.String, str]) -> 'BlockReferencesInfo': ...
    def setNextId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setPreviousId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def toString(self) -> java.lang.String: ...

class BlockSummary:
    def __init__(self): ...
    def block(self, fullBlockInfo: 'FullBlockInfo') -> 'BlockSummary': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getBlock(self) -> 'FullBlockInfo': ...
    def getReferences(self) -> BlockReferencesInfo: ...
    def hashCode(self) -> int: ...
    def references(self, blockReferencesInfo: BlockReferencesInfo) -> 'BlockSummary': ...
    def setBlock(self, fullBlockInfo: 'FullBlockInfo') -> None: ...
    def setReferences(self, blockReferencesInfo: BlockReferencesInfo) -> None: ...
    def toString(self) -> java.lang.String: ...

class BoxQuery:
    def __init__(self): ...
    def addAssetsItem(self, string: typing.Union[java.lang.String, str]) -> 'BoxQuery': ...
    def assets(self, list: java.util.List[typing.Union[java.lang.String, str]]) -> 'BoxQuery': ...
    def constants(self, map: typing.Union[java.util.Map[typing.Union[java.lang.String, str], typing.Union[java.lang.String, str]], typing.Mapping[typing.Union[java.lang.String, str], typing.Union[java.lang.String, str]]]) -> 'BoxQuery': ...
    def equals(self, object: typing.Any) -> bool: ...
    def ergoTreeTemplateHash(self, string: typing.Union[java.lang.String, str]) -> 'BoxQuery': ...
    def getAssets(self) -> java.util.List[java.lang.String]: ...
    def getConstants(self) -> java.util.Map[java.lang.String, java.lang.String]: ...
    def getErgoTreeTemplateHash(self) -> java.lang.String: ...
    def getRegisters(self) -> java.util.Map[java.lang.String, java.lang.String]: ...
    def hashCode(self) -> int: ...
    def putConstantsItem(self, string: typing.Union[java.lang.String, str], string2: typing.Union[java.lang.String, str]) -> 'BoxQuery': ...
    def putRegistersItem(self, string: typing.Union[java.lang.String, str], string2: typing.Union[java.lang.String, str]) -> 'BoxQuery': ...
    def registers(self, map: typing.Union[java.util.Map[typing.Union[java.lang.String, str], typing.Union[java.lang.String, str]], typing.Mapping[typing.Union[java.lang.String, str], typing.Union[java.lang.String, str]]]) -> 'BoxQuery': ...
    def setAssets(self, list: java.util.List[typing.Union[java.lang.String, str]]) -> None: ...
    def setConstants(self, map: typing.Union[java.util.Map[typing.Union[java.lang.String, str], typing.Union[java.lang.String, str]], typing.Mapping[typing.Union[java.lang.String, str], typing.Union[java.lang.String, str]]]) -> None: ...
    def setErgoTreeTemplateHash(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setRegisters(self, map: typing.Union[java.util.Map[typing.Union[java.lang.String, str], typing.Union[java.lang.String, str]], typing.Mapping[typing.Union[java.lang.String, str], typing.Union[java.lang.String, str]]]) -> None: ...
    def toString(self) -> java.lang.String: ...

class DataInputInfo:
    def __init__(self): ...
    def addAssetsItem(self, assetInstanceInfo: AssetInstanceInfo) -> 'DataInputInfo': ...
    def additionalRegisters(self, additionalRegisters: AdditionalRegisters) -> 'DataInputInfo': ...
    def address(self, string: typing.Union[java.lang.String, str]) -> 'DataInputInfo': ...
    def assets(self, list: java.util.List[AssetInstanceInfo]) -> 'DataInputInfo': ...
    def boxId(self, string: typing.Union[java.lang.String, str]) -> 'DataInputInfo': ...
    def equals(self, object: typing.Any) -> bool: ...
    def ergoTree(self, string: typing.Union[java.lang.String, str]) -> 'DataInputInfo': ...
    def getAdditionalRegisters(self) -> AdditionalRegisters: ...
    def getAddress(self) -> java.lang.String: ...
    def getAssets(self) -> java.util.List[AssetInstanceInfo]: ...
    def getBoxId(self) -> java.lang.String: ...
    def getErgoTree(self) -> java.lang.String: ...
    def getIndex(self) -> int: ...
    def getOutputBlockId(self) -> java.lang.String: ...
    def getOutputIndex(self) -> int: ...
    def getOutputTransactionId(self) -> java.lang.String: ...
    def getValue(self) -> int: ...
    def hashCode(self) -> int: ...
    def index(self, integer: int) -> 'DataInputInfo': ...
    def outputBlockId(self, string: typing.Union[java.lang.String, str]) -> 'DataInputInfo': ...
    def outputIndex(self, integer: int) -> 'DataInputInfo': ...
    def outputTransactionId(self, string: typing.Union[java.lang.String, str]) -> 'DataInputInfo': ...
    def setAdditionalRegisters(self, additionalRegisters: AdditionalRegisters) -> None: ...
    def setAddress(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setAssets(self, list: java.util.List[AssetInstanceInfo]) -> None: ...
    def setBoxId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setErgoTree(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setIndex(self, integer: int) -> None: ...
    def setOutputBlockId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setOutputIndex(self, integer: int) -> None: ...
    def setOutputTransactionId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setValue(self, long: int) -> None: ...
    def toString(self) -> java.lang.String: ...
    def value(self, long: int) -> 'DataInputInfo': ...

class DataInputInfo1:
    def __init__(self): ...
    def address(self, string: typing.Union[java.lang.String, str]) -> 'DataInputInfo1': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getAddress(self) -> java.lang.String: ...
    def getId(self) -> java.lang.String: ...
    def getIndex(self) -> int: ...
    def getOutputIndex(self) -> int: ...
    def getOutputTransactionId(self) -> java.lang.String: ...
    def getTransactionId(self) -> java.lang.String: ...
    def getValue(self) -> int: ...
    def hashCode(self) -> int: ...
    def id(self, string: typing.Union[java.lang.String, str]) -> 'DataInputInfo1': ...
    def index(self, integer: int) -> 'DataInputInfo1': ...
    def outputIndex(self, integer: int) -> 'DataInputInfo1': ...
    def outputTransactionId(self, string: typing.Union[java.lang.String, str]) -> 'DataInputInfo1': ...
    def setAddress(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setIndex(self, integer: int) -> None: ...
    def setOutputIndex(self, integer: int) -> None: ...
    def setOutputTransactionId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setTransactionId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setValue(self, long: int) -> None: ...
    def toString(self) -> java.lang.String: ...
    def transactionId(self, string: typing.Union[java.lang.String, str]) -> 'DataInputInfo1': ...
    def value(self, long: int) -> 'DataInputInfo1': ...

class EpochParameters:
    def __init__(self): ...
    def blockVersion(self, integer: int) -> 'EpochParameters': ...
    def dataInputCost(self, integer: int) -> 'EpochParameters': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getBlockVersion(self) -> int: ...
    def getDataInputCost(self) -> int: ...
    def getHeight(self) -> int: ...
    def getId(self) -> int: ...
    def getInputCost(self) -> int: ...
    def getMaxBlockCost(self) -> int: ...
    def getMaxBlockSize(self) -> int: ...
    def getMinValuePerByte(self) -> int: ...
    def getOutputCost(self) -> int: ...
    def getStorageFeeFactor(self) -> int: ...
    def getTokenAccessCost(self) -> int: ...
    def hashCode(self) -> int: ...
    def height(self, integer: int) -> 'EpochParameters': ...
    def id(self, integer: int) -> 'EpochParameters': ...
    def inputCost(self, integer: int) -> 'EpochParameters': ...
    def maxBlockCost(self, integer: int) -> 'EpochParameters': ...
    def maxBlockSize(self, integer: int) -> 'EpochParameters': ...
    def minValuePerByte(self, integer: int) -> 'EpochParameters': ...
    def outputCost(self, integer: int) -> 'EpochParameters': ...
    def setBlockVersion(self, integer: int) -> None: ...
    def setDataInputCost(self, integer: int) -> None: ...
    def setHeight(self, integer: int) -> None: ...
    def setId(self, integer: int) -> None: ...
    def setInputCost(self, integer: int) -> None: ...
    def setMaxBlockCost(self, integer: int) -> None: ...
    def setMaxBlockSize(self, integer: int) -> None: ...
    def setMinValuePerByte(self, integer: int) -> None: ...
    def setOutputCost(self, integer: int) -> None: ...
    def setStorageFeeFactor(self, integer: int) -> None: ...
    def setTokenAccessCost(self, integer: int) -> None: ...
    def storageFeeFactor(self, integer: int) -> 'EpochParameters': ...
    def toString(self) -> java.lang.String: ...
    def tokenAccessCost(self, integer: int) -> 'EpochParameters': ...

class Fields(java.util.HashMap[java.lang.String, java.lang.String]):
    def __init__(self): ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> java.lang.String: ...

class FullBlockInfo:
    def __init__(self): ...
    def adProofs(self, string: typing.Union[java.lang.String, str]) -> 'FullBlockInfo': ...
    def addBlockTransactionsItem(self, transactionInfo1: 'TransactionInfo1') -> 'FullBlockInfo': ...
    def blockTransactions(self, list: java.util.List['TransactionInfo1']) -> 'FullBlockInfo': ...
    def equals(self, object: typing.Any) -> bool: ...
    def extension(self, blockExtensionInfo: BlockExtensionInfo) -> 'FullBlockInfo': ...
    def getAdProofs(self) -> java.lang.String: ...
    def getBlockTransactions(self) -> java.util.List['TransactionInfo1']: ...
    def getExtension(self) -> BlockExtensionInfo: ...
    def getHeader(self) -> 'HeaderInfo': ...
    def hashCode(self) -> int: ...
    def header(self, headerInfo: 'HeaderInfo') -> 'FullBlockInfo': ...
    def setAdProofs(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setBlockTransactions(self, list: java.util.List['TransactionInfo1']) -> None: ...
    def setExtension(self, blockExtensionInfo: BlockExtensionInfo) -> None: ...
    def setHeader(self, headerInfo: 'HeaderInfo') -> None: ...
    def toString(self) -> java.lang.String: ...

class HeaderInfo:
    def __init__(self): ...
    def adProofsRoot(self, string: typing.Union[java.lang.String, str]) -> 'HeaderInfo': ...
    def difficulty(self, string: typing.Union[java.lang.String, str]) -> 'HeaderInfo': ...
    def epoch(self, integer: int) -> 'HeaderInfo': ...
    def equals(self, object: typing.Any) -> bool: ...
    def extensionHash(self, string: typing.Union[java.lang.String, str]) -> 'HeaderInfo': ...
    def getAdProofsRoot(self) -> java.lang.String: ...
    def getDifficulty(self) -> java.lang.String: ...
    def getEpoch(self) -> int: ...
    def getExtensionHash(self) -> java.lang.String: ...
    def getHeight(self) -> int: ...
    def getId(self) -> java.lang.String: ...
    def getNBits(self) -> int: ...
    def getParentId(self) -> java.lang.String: ...
    def getPowSolutions(self) -> 'PowSolutionInfo': ...
    def getSize(self) -> int: ...
    def getStateRoot(self) -> java.lang.String: ...
    def getTimestamp(self) -> int: ...
    def getTransactionsRoot(self) -> java.lang.String: ...
    def getVersion(self) -> int: ...
    def getVotes(self) -> java.util.List[int]: ...
    def hashCode(self) -> int: ...
    def height(self, integer: int) -> 'HeaderInfo': ...
    def id(self, string: typing.Union[java.lang.String, str]) -> 'HeaderInfo': ...
    def nBits(self, long: int) -> 'HeaderInfo': ...
    def parentId(self, string: typing.Union[java.lang.String, str]) -> 'HeaderInfo': ...
    def powSolutions(self, powSolutionInfo: 'PowSolutionInfo') -> 'HeaderInfo': ...
    def setAdProofsRoot(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setDifficulty(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setEpoch(self, integer: int) -> None: ...
    def setExtensionHash(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setHeight(self, integer: int) -> None: ...
    def setId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setNBits(self, long: int) -> None: ...
    def setParentId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setPowSolutions(self, powSolutionInfo: 'PowSolutionInfo') -> None: ...
    def setSize(self, integer: int) -> None: ...
    def setStateRoot(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setTimestamp(self, long: int) -> None: ...
    def setTransactionsRoot(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setVersion(self, integer: int) -> None: ...
    def setVotes(self, list: java.util.List[int]) -> None: ...
    def size(self, integer: int) -> 'HeaderInfo': ...
    def stateRoot(self, string: typing.Union[java.lang.String, str]) -> 'HeaderInfo': ...
    def timestamp(self, long: int) -> 'HeaderInfo': ...
    def toString(self) -> java.lang.String: ...
    def transactionsRoot(self, string: typing.Union[java.lang.String, str]) -> 'HeaderInfo': ...
    def version(self, integer: int) -> 'HeaderInfo': ...
    def votes(self, list: java.util.List[int]) -> 'HeaderInfo': ...

class InputInfo:
    def __init__(self): ...
    def addAssetsItem(self, assetInstanceInfo: AssetInstanceInfo) -> 'InputInfo': ...
    def additionalRegisters(self, additionalRegisters: AdditionalRegisters) -> 'InputInfo': ...
    def address(self, string: typing.Union[java.lang.String, str]) -> 'InputInfo': ...
    def assets(self, list: java.util.List[AssetInstanceInfo]) -> 'InputInfo': ...
    def boxId(self, string: typing.Union[java.lang.String, str]) -> 'InputInfo': ...
    def equals(self, object: typing.Any) -> bool: ...
    def ergoTree(self, string: typing.Union[java.lang.String, str]) -> 'InputInfo': ...
    def getAdditionalRegisters(self) -> AdditionalRegisters: ...
    def getAddress(self) -> java.lang.String: ...
    def getAssets(self) -> java.util.List[AssetInstanceInfo]: ...
    def getBoxId(self) -> java.lang.String: ...
    def getErgoTree(self) -> java.lang.String: ...
    def getIndex(self) -> int: ...
    def getOutputBlockId(self) -> java.lang.String: ...
    def getOutputIndex(self) -> int: ...
    def getOutputTransactionId(self) -> java.lang.String: ...
    def getSpendingProof(self) -> java.lang.String: ...
    def getValue(self) -> int: ...
    def hashCode(self) -> int: ...
    def index(self, integer: int) -> 'InputInfo': ...
    def outputBlockId(self, string: typing.Union[java.lang.String, str]) -> 'InputInfo': ...
    def outputIndex(self, integer: int) -> 'InputInfo': ...
    def outputTransactionId(self, string: typing.Union[java.lang.String, str]) -> 'InputInfo': ...
    def setAdditionalRegisters(self, additionalRegisters: AdditionalRegisters) -> None: ...
    def setAddress(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setAssets(self, list: java.util.List[AssetInstanceInfo]) -> None: ...
    def setBoxId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setErgoTree(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setIndex(self, integer: int) -> None: ...
    def setOutputBlockId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setOutputIndex(self, integer: int) -> None: ...
    def setOutputTransactionId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setSpendingProof(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setValue(self, long: int) -> None: ...
    def spendingProof(self, string: typing.Union[java.lang.String, str]) -> 'InputInfo': ...
    def toString(self) -> java.lang.String: ...
    def value(self, long: int) -> 'InputInfo': ...

class InputInfo1:
    def __init__(self): ...
    def address(self, string: typing.Union[java.lang.String, str]) -> 'InputInfo1': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getAddress(self) -> java.lang.String: ...
    def getId(self) -> java.lang.String: ...
    def getIndex(self) -> int: ...
    def getOutputIndex(self) -> int: ...
    def getOutputTransactionId(self) -> java.lang.String: ...
    def getSpendingProof(self) -> java.lang.String: ...
    def getTransactionId(self) -> java.lang.String: ...
    def getValue(self) -> int: ...
    def hashCode(self) -> int: ...
    def id(self, string: typing.Union[java.lang.String, str]) -> 'InputInfo1': ...
    def index(self, integer: int) -> 'InputInfo1': ...
    def outputIndex(self, integer: int) -> 'InputInfo1': ...
    def outputTransactionId(self, string: typing.Union[java.lang.String, str]) -> 'InputInfo1': ...
    def setAddress(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setIndex(self, integer: int) -> None: ...
    def setOutputIndex(self, integer: int) -> None: ...
    def setOutputTransactionId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setSpendingProof(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setTransactionId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setValue(self, long: int) -> None: ...
    def spendingProof(self, string: typing.Union[java.lang.String, str]) -> 'InputInfo1': ...
    def toString(self) -> java.lang.String: ...
    def transactionId(self, string: typing.Union[java.lang.String, str]) -> 'InputInfo1': ...
    def value(self, long: int) -> 'InputInfo1': ...

_Items__T = typing.TypeVar('_Items__T')  # <T>
class Items(typing.Generic[_Items__T]):
    def __init__(self): ...
    def addItemsItem(self, t: _Items__T) -> 'Items': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getItems(self) -> java.util.List[_Items__T]: ...
    def getTotal(self) -> int: ...
    def hashCode(self) -> int: ...
    def items(self, list: java.util.List[_Items__T]) -> 'Items': ...
    def setItems(self, list: java.util.List[_Items__T]) -> None: ...
    def setTotal(self, integer: int) -> None: ...
    def toString(self) -> java.lang.String: ...
    def total(self, integer: int) -> 'Items': ...

class MapV(java.util.HashMap[java.lang.String, java.lang.String]):
    def __init__(self): ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> java.lang.String: ...

class MinerInfo:
    def __init__(self): ...
    def address(self, string: typing.Union[java.lang.String, str]) -> 'MinerInfo': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getAddress(self) -> java.lang.String: ...
    def getName(self) -> java.lang.String: ...
    def hashCode(self) -> int: ...
    def name(self, string: typing.Union[java.lang.String, str]) -> 'MinerInfo': ...
    def setAddress(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setName(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def toString(self) -> java.lang.String: ...

class NotFound:
    def __init__(self): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getReason(self) -> java.lang.String: ...
    def getStatus(self) -> int: ...
    def hashCode(self) -> int: ...
    def reason(self, string: typing.Union[java.lang.String, str]) -> 'NotFound': ...
    def setReason(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setStatus(self, integer: int) -> None: ...
    def status(self, integer: int) -> 'NotFound': ...
    def toString(self) -> java.lang.String: ...

class OneOfListOutputInfo: ...

class OutputInfo:
    def __init__(self): ...
    def addAssetsItem(self, assetInstanceInfo: AssetInstanceInfo) -> 'OutputInfo': ...
    def additionalRegisters(self, additionalRegisters: AdditionalRegisters) -> 'OutputInfo': ...
    def address(self, string: typing.Union[java.lang.String, str]) -> 'OutputInfo': ...
    def assets(self, list: java.util.List[AssetInstanceInfo]) -> 'OutputInfo': ...
    def blockId(self, string: typing.Union[java.lang.String, str]) -> 'OutputInfo': ...
    def boxId(self, string: typing.Union[java.lang.String, str]) -> 'OutputInfo': ...
    def creationHeight(self, integer: int) -> 'OutputInfo': ...
    def equals(self, object: typing.Any) -> bool: ...
    def ergoTree(self, string: typing.Union[java.lang.String, str]) -> 'OutputInfo': ...
    def getAdditionalRegisters(self) -> AdditionalRegisters: ...
    def getAddress(self) -> java.lang.String: ...
    def getAssets(self) -> java.util.List[AssetInstanceInfo]: ...
    def getBlockId(self) -> java.lang.String: ...
    def getBoxId(self) -> java.lang.String: ...
    def getCreationHeight(self) -> int: ...
    def getErgoTree(self) -> java.lang.String: ...
    def getIndex(self) -> int: ...
    def getSettlementHeight(self) -> int: ...
    def getSpentTransactionId(self) -> java.lang.String: ...
    def getTransactionId(self) -> java.lang.String: ...
    def getValue(self) -> int: ...
    def hashCode(self) -> int: ...
    def index(self, integer: int) -> 'OutputInfo': ...
    def isMainChain(self) -> bool: ...
    def mainChain(self, boolean: bool) -> 'OutputInfo': ...
    def setAdditionalRegisters(self, additionalRegisters: AdditionalRegisters) -> None: ...
    def setAddress(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setAssets(self, list: java.util.List[AssetInstanceInfo]) -> None: ...
    def setBlockId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setBoxId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setCreationHeight(self, integer: int) -> None: ...
    def setErgoTree(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setIndex(self, integer: int) -> None: ...
    def setMainChain(self, boolean: bool) -> None: ...
    def setSettlementHeight(self, integer: int) -> None: ...
    def setSpentTransactionId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setTransactionId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setValue(self, long: int) -> None: ...
    def settlementHeight(self, integer: int) -> 'OutputInfo': ...
    def spentTransactionId(self, string: typing.Union[java.lang.String, str]) -> 'OutputInfo': ...
    def toString(self) -> java.lang.String: ...
    def transactionId(self, string: typing.Union[java.lang.String, str]) -> 'OutputInfo': ...
    def value(self, long: int) -> 'OutputInfo': ...

class OutputInfo1:
    def __init__(self): ...
    def addAssetsItem(self, assetInstanceInfo: AssetInstanceInfo) -> 'OutputInfo1': ...
    def additionalRegisters(self, additionalRegisters1: AdditionalRegisters1) -> 'OutputInfo1': ...
    def address(self, string: typing.Union[java.lang.String, str]) -> 'OutputInfo1': ...
    def assets(self, list: java.util.List[AssetInstanceInfo]) -> 'OutputInfo1': ...
    def creationHeight(self, integer: int) -> 'OutputInfo1': ...
    def equals(self, object: typing.Any) -> bool: ...
    def ergoTree(self, string: typing.Union[java.lang.String, str]) -> 'OutputInfo1': ...
    def getAdditionalRegisters(self) -> AdditionalRegisters1: ...
    def getAddress(self) -> java.lang.String: ...
    def getAssets(self) -> java.util.List[AssetInstanceInfo]: ...
    def getCreationHeight(self) -> int: ...
    def getErgoTree(self) -> java.lang.String: ...
    def getId(self) -> java.lang.String: ...
    def getIndex(self) -> int: ...
    def getSpentTransactionId(self) -> java.lang.String: ...
    def getTxId(self) -> java.lang.String: ...
    def getValue(self) -> int: ...
    def hashCode(self) -> int: ...
    def id(self, string: typing.Union[java.lang.String, str]) -> 'OutputInfo1': ...
    def index(self, integer: int) -> 'OutputInfo1': ...
    def isMainChain(self) -> bool: ...
    def mainChain(self, boolean: bool) -> 'OutputInfo1': ...
    def setAdditionalRegisters(self, additionalRegisters1: AdditionalRegisters1) -> None: ...
    def setAddress(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setAssets(self, list: java.util.List[AssetInstanceInfo]) -> None: ...
    def setCreationHeight(self, integer: int) -> None: ...
    def setErgoTree(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setIndex(self, integer: int) -> None: ...
    def setMainChain(self, boolean: bool) -> None: ...
    def setSpentTransactionId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setTxId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setValue(self, long: int) -> None: ...
    def spentTransactionId(self, string: typing.Union[java.lang.String, str]) -> 'OutputInfo1': ...
    def toString(self) -> java.lang.String: ...
    def txId(self, string: typing.Union[java.lang.String, str]) -> 'OutputInfo1': ...
    def value(self, long: int) -> 'OutputInfo1': ...

class PowSolutionInfo:
    def __init__(self): ...
    def d(self, string: typing.Union[java.lang.String, str]) -> 'PowSolutionInfo': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getD(self) -> java.lang.String: ...
    def getN(self) -> java.lang.String: ...
    def getPk(self) -> java.lang.String: ...
    def getW(self) -> java.lang.String: ...
    def hashCode(self) -> int: ...
    def n(self, string: typing.Union[java.lang.String, str]) -> 'PowSolutionInfo': ...
    def pk(self, string: typing.Union[java.lang.String, str]) -> 'PowSolutionInfo': ...
    def setD(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setN(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setPk(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setW(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def toString(self) -> java.lang.String: ...
    def w(self, string: typing.Union[java.lang.String, str]) -> 'PowSolutionInfo': ...

class TokenAmount:
    def __init__(self): ...
    def amount(self, long: int) -> 'TokenAmount': ...
    def decimals(self, integer: int) -> 'TokenAmount': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getAmount(self) -> int: ...
    def getDecimals(self) -> int: ...
    def getName(self) -> java.lang.String: ...
    def getTokenId(self) -> java.lang.String: ...
    def hashCode(self) -> int: ...
    def name(self, string: typing.Union[java.lang.String, str]) -> 'TokenAmount': ...
    def setAmount(self, long: int) -> None: ...
    def setDecimals(self, integer: int) -> None: ...
    def setName(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setTokenId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def toString(self) -> java.lang.String: ...
    def tokenId(self, string: typing.Union[java.lang.String, str]) -> 'TokenAmount': ...

class TokenInfo:
    def __init__(self): ...
    def boxId(self, string: typing.Union[java.lang.String, str]) -> 'TokenInfo': ...
    def decimals(self, integer: int) -> 'TokenInfo': ...
    def description(self, string: typing.Union[java.lang.String, str]) -> 'TokenInfo': ...
    def emissionAmount(self, long: int) -> 'TokenInfo': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getBoxId(self) -> java.lang.String: ...
    def getDecimals(self) -> int: ...
    def getDescription(self) -> java.lang.String: ...
    def getEmissionAmount(self) -> int: ...
    def getId(self) -> java.lang.String: ...
    def getName(self) -> java.lang.String: ...
    def getType(self) -> java.lang.String: ...
    def hashCode(self) -> int: ...
    def id(self, string: typing.Union[java.lang.String, str]) -> 'TokenInfo': ...
    def name(self, string: typing.Union[java.lang.String, str]) -> 'TokenInfo': ...
    def setBoxId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setDecimals(self, integer: int) -> None: ...
    def setDescription(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setEmissionAmount(self, long: int) -> None: ...
    def setId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setName(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setType(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def toString(self) -> java.lang.String: ...
    def type(self, string: typing.Union[java.lang.String, str]) -> 'TokenInfo': ...

class TotalBalance:
    def __init__(self): ...
    def confirmed(self, balance: Balance) -> 'TotalBalance': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getConfirmed(self) -> Balance: ...
    def getUnconfirmed(self) -> Balance: ...
    def hashCode(self) -> int: ...
    def setConfirmed(self, balance: Balance) -> None: ...
    def setUnconfirmed(self, balance: Balance) -> None: ...
    def toString(self) -> java.lang.String: ...
    def unconfirmed(self, balance: Balance) -> 'TotalBalance': ...

class TransactionInfo:
    def __init__(self): ...
    def addDataInputsItem(self, dataInputInfo: DataInputInfo) -> 'TransactionInfo': ...
    def addInputsItem(self, inputInfo: InputInfo) -> 'TransactionInfo': ...
    def addOutputsItem(self, outputInfo: OutputInfo) -> 'TransactionInfo': ...
    def blockId(self, string: typing.Union[java.lang.String, str]) -> 'TransactionInfo': ...
    def dataInputs(self, list: java.util.List[DataInputInfo]) -> 'TransactionInfo': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getBlockId(self) -> java.lang.String: ...
    def getDataInputs(self) -> java.util.List[DataInputInfo]: ...
    def getId(self) -> java.lang.String: ...
    def getInclusionHeight(self) -> int: ...
    def getIndex(self) -> int: ...
    def getInputs(self) -> java.util.List[InputInfo]: ...
    def getNumConfirmations(self) -> int: ...
    def getOutputs(self) -> java.util.List[OutputInfo]: ...
    def getSize(self) -> int: ...
    def getTimestamp(self) -> int: ...
    def hashCode(self) -> int: ...
    def id(self, string: typing.Union[java.lang.String, str]) -> 'TransactionInfo': ...
    def inclusionHeight(self, integer: int) -> 'TransactionInfo': ...
    def index(self, integer: int) -> 'TransactionInfo': ...
    def inputs(self, list: java.util.List[InputInfo]) -> 'TransactionInfo': ...
    def numConfirmations(self, integer: int) -> 'TransactionInfo': ...
    def outputs(self, list: java.util.List[OutputInfo]) -> 'TransactionInfo': ...
    def setBlockId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setDataInputs(self, list: java.util.List[DataInputInfo]) -> None: ...
    def setId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setInclusionHeight(self, integer: int) -> None: ...
    def setIndex(self, integer: int) -> None: ...
    def setInputs(self, list: java.util.List[InputInfo]) -> None: ...
    def setNumConfirmations(self, integer: int) -> None: ...
    def setOutputs(self, list: java.util.List[OutputInfo]) -> None: ...
    def setSize(self, integer: int) -> None: ...
    def setTimestamp(self, long: int) -> None: ...
    def size(self, integer: int) -> 'TransactionInfo': ...
    def timestamp(self, long: int) -> 'TransactionInfo': ...
    def toString(self) -> java.lang.String: ...

class TransactionInfo1:
    def __init__(self): ...
    def addDataInputsItem(self, dataInputInfo1: DataInputInfo1) -> 'TransactionInfo1': ...
    def addInputsItem(self, inputInfo1: InputInfo1) -> 'TransactionInfo1': ...
    def addOutputsItem(self, outputInfo1: OutputInfo1) -> 'TransactionInfo1': ...
    def confirmationsCount(self, integer: int) -> 'TransactionInfo1': ...
    def dataInputs(self, list: java.util.List[DataInputInfo1]) -> 'TransactionInfo1': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getConfirmationsCount(self) -> int: ...
    def getDataInputs(self) -> java.util.List[DataInputInfo1]: ...
    def getHeaderId(self) -> java.lang.String: ...
    def getId(self) -> java.lang.String: ...
    def getInclusionHeight(self) -> int: ...
    def getIndex(self) -> int: ...
    def getInputs(self) -> java.util.List[InputInfo1]: ...
    def getOutputs(self) -> java.util.List[OutputInfo1]: ...
    def getTimestamp(self) -> int: ...
    def hashCode(self) -> int: ...
    def headerId(self, string: typing.Union[java.lang.String, str]) -> 'TransactionInfo1': ...
    def id(self, string: typing.Union[java.lang.String, str]) -> 'TransactionInfo1': ...
    def inclusionHeight(self, long: int) -> 'TransactionInfo1': ...
    def index(self, integer: int) -> 'TransactionInfo1': ...
    def inputs(self, list: java.util.List[InputInfo1]) -> 'TransactionInfo1': ...
    def outputs(self, list: java.util.List[OutputInfo1]) -> 'TransactionInfo1': ...
    def setConfirmationsCount(self, integer: int) -> None: ...
    def setDataInputs(self, list: java.util.List[DataInputInfo1]) -> None: ...
    def setHeaderId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setId(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setInclusionHeight(self, long: int) -> None: ...
    def setIndex(self, integer: int) -> None: ...
    def setInputs(self, list: java.util.List[InputInfo1]) -> None: ...
    def setOutputs(self, list: java.util.List[OutputInfo1]) -> None: ...
    def setTimestamp(self, long: int) -> None: ...
    def timestamp(self, long: int) -> 'TransactionInfo1': ...
    def toString(self) -> java.lang.String: ...

class UnknownErr:
    def __init__(self): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getReason(self) -> java.lang.String: ...
    def getStatus(self) -> int: ...
    def hashCode(self) -> int: ...
    def reason(self, string: typing.Union[java.lang.String, str]) -> 'UnknownErr': ...
    def setReason(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setStatus(self, integer: int) -> None: ...
    def status(self, integer: int) -> 'UnknownErr': ...
    def toString(self) -> java.lang.String: ...

class ItemsA(Items[OutputInfo]):
    def __init__(self): ...

class ListOutputInfo(OneOfListOutputInfo):
    def __init__(self): ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> java.lang.String: ...

class Nil(OneOfListOutputInfo):
    def __init__(self): ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> java.lang.String: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.explorer.client.model")``.

    AdditionalRegister: typing.Type[AdditionalRegister]
    AdditionalRegisters: typing.Type[AdditionalRegisters]
    AdditionalRegisters1: typing.Type[AdditionalRegisters1]
    AssetInfo: typing.Type[AssetInfo]
    AssetInstanceInfo: typing.Type[AssetInstanceInfo]
    BadRequest: typing.Type[BadRequest]
    Balance: typing.Type[Balance]
    BlockExtensionInfo: typing.Type[BlockExtensionInfo]
    BlockInfo: typing.Type[BlockInfo]
    BlockReferencesInfo: typing.Type[BlockReferencesInfo]
    BlockSummary: typing.Type[BlockSummary]
    BoxQuery: typing.Type[BoxQuery]
    DataInputInfo: typing.Type[DataInputInfo]
    DataInputInfo1: typing.Type[DataInputInfo1]
    EpochParameters: typing.Type[EpochParameters]
    Fields: typing.Type[Fields]
    FullBlockInfo: typing.Type[FullBlockInfo]
    HeaderInfo: typing.Type[HeaderInfo]
    InputInfo: typing.Type[InputInfo]
    InputInfo1: typing.Type[InputInfo1]
    Items: typing.Type[Items]
    ItemsA: typing.Type[ItemsA]
    ListOutputInfo: typing.Type[ListOutputInfo]
    MapV: typing.Type[MapV]
    MinerInfo: typing.Type[MinerInfo]
    Nil: typing.Type[Nil]
    NotFound: typing.Type[NotFound]
    OneOfListOutputInfo: typing.Type[OneOfListOutputInfo]
    OutputInfo: typing.Type[OutputInfo]
    OutputInfo1: typing.Type[OutputInfo1]
    PowSolutionInfo: typing.Type[PowSolutionInfo]
    TokenAmount: typing.Type[TokenAmount]
    TokenInfo: typing.Type[TokenInfo]
    TotalBalance: typing.Type[TotalBalance]
    TransactionInfo: typing.Type[TransactionInfo]
    TransactionInfo1: typing.Type[TransactionInfo1]
    UnknownErr: typing.Type[UnknownErr]
